(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    192558,       4300]
NotebookOptionsPosition[    186912,       4213]
NotebookOutlinePosition[    187541,       4236]
CellTagsIndexPosition[    187498,       4233]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 20 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}, {
   3.890973965108789*^9, 3.8909739653874283`*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5a7d6619-6bae-4c0f-83f3-957cc8244682"],

Cell["Chapter 7, Section 7.10, Figure 7.16", "Section",ExpressionUUID->"ed1aa644-8af7-45fd-90c6-3a7e9c066dbb"],

Cell[TextData[{
 "We start by defining ",
 StyleBox["laplace", "Input"],
 ", a function to calculate a Laplace coefficient by evaluating an integral \
(see Eq.(6.67))."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c125199a-ba4d-48c1-a4cd-efb6154951a4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"laplace", "[", " ", 
    RowBox[{"s_", ",", " ", "jj_", ",", " ", "aa_"}], " ", "]"}], " ", ":=", 
   " ", "\n", "    ", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"aa", " ", "!=", " ", "0"}], ",", "\n", "       ", 
     RowBox[{"NIntegrate", "[", " ", 
      RowBox[{
       RowBox[{"N", "[", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "/", "Pi"}], ")"}], "*", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Cos", "[", 
            RowBox[{"jj", "*", "x"}], "]"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"2", "aa", "*", 
               RowBox[{"Cos", "[", "x", "]"}]}], "+", 
              RowBox[{"aa", "^", "2"}]}], ")"}], "^", "s"}], ")"}]}]}], " ", 
        "]"}], ",", " ", "\n", "               ", 
       RowBox[{"{", 
        RowBox[{"x", ",", " ", "0", ",", " ", "Pi"}], "}"}]}], " ", "]"}], 
     ",", "\n", "       ", "0"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8706857067515182`*^9, 3.8706857067557383`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"6b115696-9890-42b3-8505-a71b37be217c"],

Cell[TextData[{
 "Now we define a function ",
 StyleBox["BrouwerProper", "Input"],
 ", a slightly longer version of the function ",
 StyleBox["Brouwer", "Input"],
 " from ",
 StyleBox["Sect.7.8.nb",
  FontWeight->"Bold"],
 ", that returns the forced orbital elements of a test particle with \
semi-major axis ",
 StyleBox["atest", "Input"],
 " at year ",
 StyleBox["year", "Input"],
 " using the Brouwer & van Woerkom secular theory for the planets."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"4b41b6e1-035e-4114-b201-ae8aa72b905f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BrouwerProper", "[", 
    RowBox[{"atest_", ",", " ", "year_"}], "]"}], " ", ":=", "\n", 
   RowBox[{"Module", "[", "\n", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"m", " ", "=", " ", 
        RowBox[{"1", "/", 
         RowBox[{"{", 
          RowBox[{
          "6025607.0", ",", " ", "408662.0", ",", " ", "328912.0", ",", " ", 
           "3099774.0", ",", " ", "1047.91", ",", "\n", "         ", 
           "3500.05", ",", " ", "22970.0", ",", " ", "19360.0"}], "}"}]}]}], 
       ",", "\n", "  ", 
       RowBox[{"a", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
         "0.38710", ",", " ", "0.72333", ",", " ", "1.00002", ",", " ", 
          "1.52364", ",", " ", "5.20248", ",", "\n", "       ", "9.56329", 
          ",", " ", "19.29373", ",", " ", "30.27435"}], "}"}]}], ",", "\n", 
       "  ", 
       RowBox[{"g", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
         "5.46326", ",", " ", "7.34474", ",", " ", "17.32832", ",", " ", 
          "18.00233", ",", " ", "4.29591", ",", "\n", "       ", "27.77406", 
          ",", " ", "2.71931", ",", " ", "0.63332", ",", " ", 
          RowBox[{"-", "19.18225"}], ",", " ", "51.25222"}], "}"}]}], ",", 
       "\n", "  ", 
       RowBox[{"\[Beta]", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
         "92.182", ",", " ", "196.881", ",", " ", "335.224", ",", " ", 
          "317.948", ",", " ", "29.550", ",", "\n", "          ", "125.120", 
          ",", " ", "131.944", ",", " ", "69.021", ",", " ", "293.979", ",", 
          " ", "220.691"}], "}"}]}], ",", "\n", "  ", 
       RowBox[{"f", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5.21054"}], ",", " ", 
          RowBox[{"-", "6.57080"}], ",", " ", 
          RowBox[{"-", "18.74359"}], ",", " ", 
          RowBox[{"-", "17.63331"}], ",", " ", "\n", "       ", "0.00000", 
          ",", " ", 
          RowBox[{"-", "25.73355"}], ",", " ", 
          RowBox[{"-", "2.90266"}], ",", " ", 
          RowBox[{"-", "0.67752"}]}], "}"}]}], ",", "\n", "  ", 
       RowBox[{"\[Gamma]", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
         "19.433", ",", " ", "318.057", ",", " ", "255.031", ",", " ", 
          "296.541", ",", "\n", "           ", "107.102", ",", " ", "127.367",
           ",", " ", "315.063", ",", " ", "202.293"}], "}"}]}], ",", "\n", 
       "  ", 
       RowBox[{"eij", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "0.17454", ",", " ", "0.00610", ",", " ", "0.00392", ",", " ", 
            "0.00064", ",", " ", 
            RowBox[{"-", "0.00001"}], ",", "\n", "               ", 
            RowBox[{"-", "0.00001"}], ",", " ", "0.0", ",", " ", "0.0"}], 
           "}"}], ",", "\n", "         ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.02550"}], ",", " ", "0.02094", ",", " ", 
            "0.01634", ",", " ", "0.00290", ",", " ", 
            RowBox[{"-", "0.00001"}], ",", "\n", "               ", 
            RowBox[{"-", "0.00001"}], ",", " ", "0.0", ",", " ", "0.0"}], 
           "}"}], ",", "\n", "         ", 
          RowBox[{"{", 
           RowBox[{"0.00154", ",", " ", 
            RowBox[{"-", "0.01255"}], ",", " ", "0.01043", ",", " ", 
            "0.02972", ",", " ", "0.0", ",", "\n", "               ", 
            RowBox[{"-", "0.00001"}], ",", " ", "0.0", ",", " ", "0.0"}], 
           "}"}], ",", "\n", "         ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.00169"}], ",", " ", "0.01483", ",", " ", 
            RowBox[{"-", "0.01483"}], ",", " ", "0.07237", ",", " ", "0.0", 
            ",", "\n", "               ", 
            RowBox[{"-", "0.00001"}], ",", " ", "0.0", ",", " ", "0.0"}], 
           "}"}], ",", "\n", "         ", 
          RowBox[{"{", 
           RowBox[{
           "0.03571", ",", " ", "0.01909", ",", " ", "0.01834", ",", " ", 
            "0.01861", ",", " ", "0.04482", ",", "\n", "               ", 
            "0.03291", ",", " ", 
            RowBox[{"-", "0.03188"}], ",", " ", "0.00063"}], "}"}], ",", "\n",
           "         ", 
          RowBox[{"{", 
           RowBox[{
           "0.00096", ",", " ", "0.00006", ",", " ", "0.00283", ",", " ", 
            "0.01502", ",", " ", 
            RowBox[{"-", "0.01535"}], ",", "\n", "               ", "0.04863",
             ",", " ", 
            RowBox[{"-", "0.00248"}], ",", " ", 
            RowBox[{"-", "0.00011"}]}], "}"}], ",", "\n", "         ", 
          RowBox[{"{", 
           RowBox[{
           "0.00043", ",", " ", "0.00042", ",", " ", "0.00044", ",", " ", 
            "0.00059", ",", " ", "0.00147", ",", "\n", "               ", 
            "0.00148", ",", " ", "0.03043", ",", " ", 
            RowBox[{"-", "0.00323"}]}], "}"}], ",", "\n", "         ", 
          RowBox[{"{", 
           RowBox[{
           "0.00001", ",", " ", "0.00001", ",", " ", "0.00001", ",", " ", 
            "0.00002", ",", " ", "0.00005", ",", "\n", "               ", 
            "0.00006", ",", " ", "0.00143", ",", " ", "0.00938"}], "}"}], ",",
           "\n", "         ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.00021"}], ",", " ", 
            RowBox[{"-", "0.00011"}], ",", " ", 
            RowBox[{"-", "0.00012"}], ",", " ", 
            RowBox[{"-", "0.00020"}], ",", " ", 
            RowBox[{"-", "0.00016"}], ",", "\n", "               ", 
            RowBox[{"-", "0.00049"}], ",", " ", "0.00020", ",", " ", "0.0"}], 
           "}"}], ",", "\n", "         ", 
          RowBox[{"{", 
           RowBox[{
           "0.00010", ",", " ", "0.00004", ",", " ", "0.00015", ",", " ", 
            "0.00064", ",", " ", 
            RowBox[{"-", "0.00054"}], ",", "\n", "               ", "0.00202",
             ",", " ", 
            RowBox[{"-", "0.00016"}], ",", " ", "0.0"}], "}"}]}], "}"}]}], 
       ",", "\n", "  ", 
       RowBox[{"iij", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "0.12449", ",", " ", "0.01178", ",", " ", "0.00849", ",", " ", 
            "0.00180", ",", " ", 
            RowBox[{"-", "0.00002"}], ",", " ", "\n", "               ", 
            RowBox[{"-", "0.00003"}], ",", " ", "0.00002", ",", " ", "0.0"}], 
           "}"}], ",", "\n", "          ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.03545"}], ",", " ", "0.01004", ",", " ", 
            "0.00810", ",", " ", "0.00180", ",", " ", 
            RowBox[{"-", "0.00001"}], ",", "\n", "               ", 
            RowBox[{"-", "0.00002"}], ",", " ", "0.00001", ",", " ", "0.0"}], 
           "}"}], ",", "\n", "          ", 
          RowBox[{"{", 
           RowBox[{"0.00409", ",", " ", 
            RowBox[{"-", "0.02680"}], ",", " ", "0.02448", ",", " ", 
            RowBox[{"-", "0.03589"}], ",", " ", "0.0", ",", "\n", 
            "               ", "0.0", ",", " ", "0.0", ",", " ", "0.0"}], 
           "}"}], ",", "\n", "          ", 
          RowBox[{"{", 
           RowBox[{"0.00116", ",", " ", 
            RowBox[{"-", "0.00685"}], ",", " ", "0.00453", ",", " ", 
            "0.05025", ",", " ", "0.0", ",", "\n", "               ", 
            RowBox[{"-", "0.00002"}], ",", " ", "0.0", ",", " ", "0.0"}], 
           "}"}], ",", "\n", "          ", 
          RowBox[{"{", 
           RowBox[{
           "0.02757", ",", " ", "0.02757", ",", " ", "0.02757", ",", " ", 
            "0.02757", ",", " ", "0.02757", ",", "\n", "               ", 
            "0.02757", ",", " ", "0.02757", ",", " ", "0.02757"}], "}"}], ",",
           "\n", "          ", 
          RowBox[{"{", 
           RowBox[{
           "0.00028", ",", " ", "0.00012", ",", " ", "0.00281", ",", " ", 
            "0.00965", ",", " ", 
            RowBox[{"-", "0.00631"}], ",", "\n", "               ", "0.01572",
             ",", " ", 
            RowBox[{"-", "0.00069"}], ",", " ", 
            RowBox[{"-", "0.00008"}]}], "}"}], ",", "\n", "          ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.00332"}], ",", " ", 
            RowBox[{"-", "0.00192"}], ",", " ", 
            RowBox[{"-", "0.00173"}], ",", " ", 
            RowBox[{"-", "0.00126"}], ",", " ", 
            RowBox[{"-", "0.00096"}], ",", "\n", "               ", 
            RowBox[{"-", "0.00078"}], ",", " ", "0.01760", ",", " ", 
            RowBox[{"-", "0.00207"}]}], "}"}], ",", "\n", "          ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.00145"}], ",", " ", 
            RowBox[{"-", "0.00132"}], ",", " ", 
            RowBox[{"-", "0.00130"}], ",", " ", 
            RowBox[{"-", "0.00123"}], ",", " ", 
            RowBox[{"-", "0.00117"}], ",", "\n", "               ", 
            RowBox[{"-", "0.00113"}], ",", " ", "0.00110", ",", " ", 
            "0.01175"}], "}"}]}], "}"}]}], ",", "\n", "   ", 
       RowBox[{"ntest", "=", 
        RowBox[{"360.", "/", 
         RowBox[{"atest", "^", 
          RowBox[{"(", 
           RowBox[{"3", "/", "2"}], ")"}]}]}]}], ",", "time"}], "\n", "}"}], 
     ",", "\n", 
     RowBox[{
      RowBox[{"tg", " ", "=", " ", "g"}], ";", " ", 
      RowBox[{"tf", " ", "=", " ", "f"}], ";", " ", 
      RowBox[{"tb", " ", "=", " ", "\[Beta]"}], ";", " ", 
      RowBox[{"tga", " ", "=", " ", "\[Gamma]"}], ";", "\n", 
      RowBox[{"gr", " ", "=", " ", 
       RowBox[{"N", "[", 
        RowBox[{"g", " ", "Degree"}], "]"}]}], ";", "\n", 
      RowBox[{"fr", " ", "=", " ", 
       RowBox[{"N", "[", 
        RowBox[{"f", " ", "Degree"}], "]"}]}], ";", "\n", 
      RowBox[{"eji", " ", "=", " ", 
       RowBox[{"Transpose", "[", "eij", "]"}]}], ";", "\n", 
      RowBox[{"iji", " ", "=", " ", 
       RowBox[{"Transpose", "[", "iij", "]"}]}], ";", "\n", 
      RowBox[{"time", " ", "=", " ", 
       RowBox[{"year", "-", "1900."}]}], ";", "\n", 
      RowBox[{"h", " ", "=", " ", 
       RowBox[{"eji", ".", 
        RowBox[{"(", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"g", "*", 
               RowBox[{"time", "/", "3600."}]}], " ", "+", " ", "\[Beta]"}], 
             ")"}], " ", "Degree"}], "]"}], "]"}], ")"}]}]}], ";", "\n", 
      RowBox[{"k", " ", "=", " ", 
       RowBox[{"eji", ".", 
        RowBox[{"(", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"g", "*", 
               RowBox[{"time", "/", "3600."}]}], " ", "+", " ", "\[Beta]"}], 
             ")"}], " ", "Degree"}], "]"}], "]"}], ")"}]}]}], ";", "\n", 
      RowBox[{"e", " ", "=", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "*", 
            RowBox[{"h", "[", 
             RowBox[{"[", "j", "]"}], "]"}]}], " ", "+", " ", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "*", 
            RowBox[{"k", "[", 
             RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "8"}], "}"}]}], "]"}]}], ";", "\n", 
      RowBox[{"cp", " ", "=", " ", 
       RowBox[{"N", "[", 
        RowBox[{
         RowBox[{"ArcTan", "[", 
          RowBox[{"k", ",", "h"}], "]"}], "/", "Degree"}], "]"}]}], ";", "\n", 
      RowBox[{"p", " ", "=", " ", 
       RowBox[{"iji", ".", 
        RowBox[{"(", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"f", "*", 
               RowBox[{"time", "/", "3600."}]}], " ", "+", " ", "\[Gamma]"}], 
             ")"}], " ", "Degree"}], "]"}], "]"}], ")"}]}]}], ";", "\n", 
      RowBox[{"q", " ", "=", " ", 
       RowBox[{"iji", ".", 
        RowBox[{"(", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"f", "*", 
               RowBox[{"time", "/", "3600."}]}], " ", "+", " ", "\[Gamma]"}], 
             ")"}], " ", "Degree"}], "]"}], "]"}], ")"}]}]}], ";", "\n", 
      RowBox[{"i", " ", "=", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{
           RowBox[{"ArcSin", "[", "\n", "       ", 
            RowBox[{"Sqrt", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"p", "[", 
                RowBox[{"[", "j", "]"}], "]"}], "*", 
               RowBox[{"p", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}], " ", "+", " ", 
              RowBox[{
               RowBox[{"q", "[", 
                RowBox[{"[", "j", "]"}], "]"}], "*", 
               RowBox[{"q", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}], "]"}], "/", 
           "Degree"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "8"}], "}"}]}], "]"}]}], ";", "\n", 
      RowBox[{"om", " ", "=", " ", 
       RowBox[{"N", "[", 
        RowBox[{
         RowBox[{"ArcTan", "[", 
          RowBox[{"q", ",", "p"}], "]"}], "/", "Degree"}], "]"}]}], ";", "\n", 
      RowBox[{"alphaj", "    ", "=", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"atest", "/", "a"}], " ", "/.", " ", 
         RowBox[{"{", 
          RowBox[{"x_", " ", ":>", " ", 
           RowBox[{
            RowBox[{"1", "/", "x"}], " ", "/;", " ", 
            RowBox[{"x", ">", "1"}]}]}], "}"}]}], ")"}]}], ";", "\n", 
      RowBox[{"alphabarj", " ", "=", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"atest", "/", "a"}], " ", "/.", " ", 
         RowBox[{"{", 
          RowBox[{"x_", " ", ":>", " ", 
           RowBox[{"1", "   ", "/;", " ", 
            RowBox[{"x", ">", "1"}]}]}], "}"}]}], ")"}]}], ";", "\n", 
      RowBox[{"b321", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"laplace", "[", 
           RowBox[{
            RowBox[{"3", "/", "2"}], ",", " ", "1", ",", " ", "#"}], "]"}], 
          "&"}], ",", " ", "alphaj"}], "]"}]}], ";", "\n", 
      RowBox[{"b322", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"laplace", "[", 
           RowBox[{
            RowBox[{"3", "/", "2"}], ",", " ", "2", ",", " ", "#"}], "]"}], 
          "&"}], ",", " ", "alphaj"}], "]"}]}], ";", "\n", 
      RowBox[{"bigAA", " ", "=", "  ", 
       RowBox[{"ntest", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "/", "4"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"Plus", " ", "@@", " ", 
            RowBox[{"(", 
             RowBox[{"m", "*", "alphaj", "*", "alphabarj", "*", "b321"}], 
             ")"}]}], ")"}]}], ")"}]}]}], ";", "\n", 
      RowBox[{"bigBB", " ", "=", " ", 
       RowBox[{
        RowBox[{"-", "ntest"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "/", "4"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"Plus", " ", "@@", " ", 
            RowBox[{"(", 
             RowBox[{"m", "*", "alphaj", "*", "alphabarj", "*", "b321"}], 
             ")"}]}], ")"}]}], ")"}]}]}], ";", "\n", 
      RowBox[{"bigAj", " ", "=", " ", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"1", "/", "4"}], ")"}]}], "*", "m", "*", "ntest", "*", 
        "alphaj", "*", "alphabarj", "*", "b322"}]}], ";", "\n", 
      RowBox[{"bigBj", " ", "=", "  ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "/", "4"}], ")"}], "*", "m", "*", "ntest", "*", 
        "alphaj", "*", "alphabarj", "*", "b321"}]}], ";", "\n", 
      RowBox[{"nui", " ", "=", " ", 
       RowBox[{"bigAj", " ", ".", " ", "eji"}]}], ";", "\n", 
      RowBox[{"mui", " ", "=", " ", 
       RowBox[{"bigBj", " ", ".", " ", "iji"}]}], ";", "\n", 
      RowBox[{"h0", " ", "=", " ", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"Plus", " ", "@@", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"nui", "/", 
              RowBox[{"(", 
               RowBox[{"bigAA", "-", 
                RowBox[{"g", "/", "3600."}]}], ")"}]}], ")"}], "*", "\n", 
            "       ", 
            RowBox[{"Sin", "[", 
             RowBox[{"N", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"g", "*", 
                  RowBox[{"time", "/", "3600."}]}], " ", "+", " ", 
                 "\[Beta]"}], " ", ")"}], " ", "Degree"}], "]"}], "]"}]}], 
           ")"}]}], ")"}]}]}], ";", "\n", 
      RowBox[{"k0", " ", "=", " ", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"Plus", " ", "@@", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"nui", "/", 
              RowBox[{"(", 
               RowBox[{"bigAA", "-", 
                RowBox[{"g", "/", "3600."}]}], ")"}]}], ")"}], "*", "\n", 
            "       ", 
            RowBox[{"Cos", "[", 
             RowBox[{"N", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"g", "*", 
                  RowBox[{"time", "/", "3600."}]}], " ", "+", " ", 
                 "\[Beta]"}], " ", ")"}], " ", "Degree"}], "]"}], "]"}]}], 
           ")"}]}], ")"}]}]}], ";", "\n", 
      RowBox[{"eforced", " ", "=", " ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"h0", "^", "2"}], "+", 
         RowBox[{"k0", "^", "2"}]}], "]"}]}], ";", "\n", 
      RowBox[{"periforced", " ", "=", " ", 
       RowBox[{"N", "[", 
        RowBox[{
         RowBox[{"ArcTan", "[", 
          RowBox[{"k0", ",", "h0"}], "]"}], "/", "Degree"}], "]"}]}], ";", 
      "\n", 
      RowBox[{"p0", " ", "=", " ", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"Plus", " ", "@@", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"mui", "/", 
              RowBox[{"(", 
               RowBox[{"bigBB", "-", 
                RowBox[{"f", "/", "3600."}]}], ")"}]}], ")"}], "*", "\n", 
            "       ", 
            RowBox[{"Sin", "[", 
             RowBox[{"N", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"f", "*", 
                  RowBox[{"time", "/", "3600."}]}], " ", "+", " ", 
                 "\[Gamma]"}], ")"}], " ", "Degree"}], "]"}], "]"}]}], 
           ")"}]}], ")"}]}]}], ";", "\n", 
      RowBox[{"q0", " ", "=", " ", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"Plus", " ", "@@", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"mui", "/", 
              RowBox[{"(", 
               RowBox[{"bigBB", "-", 
                RowBox[{"f", "/", "3600."}]}], ")"}]}], ")"}], "*", "\n", 
            "       ", 
            RowBox[{"Cos", "[", 
             RowBox[{"N", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"f", "*", 
                  RowBox[{"time", "/", "3600."}]}], " ", "+", " ", 
                 "\[Gamma]"}], ")"}], " ", "Degree"}], "]"}], "]"}]}], 
           ")"}]}], ")"}]}]}], ";", "\n", 
      RowBox[{"iforced", " ", "=", " ", 
       RowBox[{"N", "[", 
        RowBox[{
         RowBox[{"ArcSin", "[", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"p0", "^", "2"}], "+", 
            RowBox[{"q0", "^", "2"}]}], "]"}], "]"}], "/", "Degree"}], 
        "]"}]}], ";", "\n", 
      RowBox[{"nodeforced", " ", "=", " ", 
       RowBox[{"N", "[", 
        RowBox[{
         RowBox[{"ArcTan", "[", 
          RowBox[{"q0", ",", "p0"}], "]"}], "/", "Degree"}], "]"}]}], ";", 
      "\n", 
      RowBox[{"N", "[", 
       RowBox[{"{", 
        RowBox[{
        "atest", ",", " ", "eforced", ",", " ", "periforced", ",", " ", 
         "iforced", ",", " ", "nodeforced"}], "}"}], "]"}]}]}], "\n", "]"}]}],
   ";"}]], "Input",
 CellChangeTimes->{{3.8706857314715233`*^9, 3.870685731476943*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"c40b1e72-4a7a-4efe-8bd9-416f4529b2b7"],

Cell["\<\
Calculate the forced elements between 2 and 4 AU for the epoch of 1997.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1719780f-8de4-4a4f-84cf-3a1da27b8d59"],

Cell[BoxData[
 RowBox[{
  RowBox[{"results", " ", "=", " ", "\n", 
   RowBox[{"N", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"BrouwerProper", "[", 
       RowBox[{"aaa", ",", " ", "1997"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"aaa", ",", " ", "2", ",", " ", "4", ",", " ", "0.01"}], 
       "}"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.870685744665613*^9, 3.87068574466999*^9}, 
   3.870690373080247*^9, 3.8706904753944683`*^9},
 CellLabel->"In[3]:=",ExpressionUUID->"7166eb21-c074-45bb-bf5c-dea5ec22c86c"],

Cell["Transpose the results ...", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"a08bf566-8ee8-4879-8e19-3cb0d2a7e628"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tres", " ", "=", " ", 
   RowBox[{"Transpose", "[", "results", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.87068575575268*^9, 3.8706857557580214`*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"57b23ba4-9550-4348-a59b-465518fe23ac"],

Cell["\<\
... and prepare lists of forced eccentricity, forced longitude of pericentre, \
forced inclination and forced longitude of ascending node as a function of \
semi-major axis.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c507b30c-7aaa-421d-8192-ab03f99aca75"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ae", " ", "=", " ", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tres", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
      RowBox[{"tres", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"acp", " ", "=", " ", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tres", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
      RowBox[{"tres", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ai", " ", "=", " ", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tres", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
      RowBox[{"tres", "[", 
       RowBox[{"[", "4", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"aom", " ", "=", " ", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tres", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
      RowBox[{"tres", "[", 
       RowBox[{"[", "5", "]"}], "]"}]}], "}"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.870685773374309*^9, 3.87068577337881*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"57174013-42ef-4692-937e-496d9f64b056"],

Cell[TextData[{
 "Select those asteroids in the first 64 and then the remaining parts of ",
 StyleBox["ae", "Input"],
 " with forced eccentricities less than 0.09.  The purpose of breaking things \
up is to take account of the singularity caused by the secular resonance near \
2.6 AU."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"4a093312-3529-47ac-8119-521634508e47"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ae1", " ", "=", " ", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"Take", "[", 
      RowBox[{"ae", ",", "64"}], "]"}], ",", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "<", "0.09"}], ")"}], "&"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.870685788527492*^9, 3.870685788532681*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"b5685f15-d73a-42c3-9a86-08694146b293"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ae2", " ", "=", " ", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"Drop", "[", 
      RowBox[{"ae", ",", "64"}], "]"}], ",", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "<", "0.09"}], ")"}], "&"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.870685795244711*^9, 3.870685795249309*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"cdab3668-331e-4d0a-9431-3ba899767a5f"],

Cell["\<\
Obtain the corresponding set of longitudes of pericentre, avoiding the \
singularity near 2 AU.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8755290208391943`*^9, 3.8755290374136457`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"91e4047d-8e65-4b31-8a8a-0c9f720970ed"],

Cell[BoxData[
 RowBox[{
  RowBox[{"acp1", " ", "=", " ", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"Take", "[", 
      RowBox[{"acp", ",", "64"}], "]"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ">", "2.05"}], ")"}], "&"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.870685811852371*^9, 3.8706858118576317`*^9}, {
  3.875528892130287*^9, 3.875528967635087*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"a1641c6c-1870-4c0f-9b2f-824ef8536360"],

Cell[BoxData[
 RowBox[{
  RowBox[{"acp2", " ", "=", " ", 
   RowBox[{"Drop", "[", 
    RowBox[{"acp", ",", "64"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.870685822514048*^9, 3.870685822521634*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"f44504b8-930b-4e3a-a9d9-2ad821643e54"],

Cell["Set the colours for each plot.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8706886125517807`*^9, 3.8706886208470783`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1088118a-c749-40cf-944a-014a651d3e46"],

Cell[BoxData[
 RowBox[{
  RowBox[{"color1", "=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8706884723044577`*^9, 3.8706884767572603`*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"8b536e59-af7d-4f88-9380-fac0d0fff6d4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"color2", "=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.870688484124298*^9, 3.870688503351976*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"84729db2-5cde-4be1-ab57-d6fc6e4abf41"],

Cell["Define the axis labels.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869373084037505*^9, 3.869373204667523*^9}, {
  3.869552502127846*^9, 3.869552527987165*^9}, {3.8695525676926813`*^9, 
  3.869552627902935*^9}, {3.869552688038094*^9, 3.8695527321988773`*^9}, {
  3.86955276584477*^9, 3.8695527789835157`*^9}, {3.869552853609722*^9, 
  3.8695529191526623`*^9}, {3.869553047085703*^9, 3.869553087120385*^9}, {
  3.870607952402626*^9, 3.870607986048612*^9}, {3.870608112694354*^9, 
  3.870608186135066*^9}, {3.870608226185451*^9, 3.8706082321707907`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1c35af96-a24b-4136-9ae5-b8ea0dace3b5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xlabel", "=", "\"\<Semi-major Axis (AU)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"y1label", "=", 
   RowBox[{"ToString", "[", 
    RowBox[{
     RowBox[{"Style", "[", 
      RowBox[{"\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
SubscriptBox[
StyleBox[\"e\", \"TI\"], \"forced\"], TraditionalForm], \"errors\" -> {}, \
\"input\" -> \"e_{\\\\rm{forced}}\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\"", ",", "color1"}], "]"}], ",", 
     "StandardForm"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"y2label", "=", 
   RowBox[{"ToString", "[", 
    RowBox[{
     RowBox[{"Style", "[", 
      RowBox[{"\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
SubscriptBox[\"\[CurlyPi]\", \"forced\"], \" \", 
RowBox[{\"(\", \"deg.\", \")\"}]}], TraditionalForm], \"errors\" -> {}, \
\"input\" -> \"\\\\varpi_{\\\\rm{forced}}\\\\,(\\\\rm{deg.})\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\"", ",", "color2"}], "]"}], ",", 
     "StandardForm"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"y1labelplain", "=", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
SubscriptBox[
StyleBox[\"e\", \"TI\"], \"forced\"], TraditionalForm], \"errors\" -> {}, \
\"input\" -> \"e_{\\\\rm{forced}}\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"y2labelplain", "=", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
SubscriptBox[\"\[CurlyPi]\", \"forced\"], \" \", 
RowBox[{\"(\", \"deg.\", \")\"}]}], TraditionalForm], \"errors\" -> {}, \
\"input\" -> \"\\\\varpi_{\\\\rm{forced}}\\\\,(\\\\rm{deg.})\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.869289947761011*^9, 3.869289969581517*^9}, {
   3.870332110433919*^9, 3.87033213656196*^9}, {3.8703321679305143`*^9, 
   3.870332169106471*^9}, 3.870333753167899*^9, 3.870333801080449*^9, {
   3.8706070315241737`*^9, 3.870607116081512*^9}, 3.870607168734023*^9, 
   3.87069254305085*^9, {3.8706925888486967`*^9, 3.870692598474683*^9}, {
   3.8755284277594767`*^9, 3.875528432902925*^9}, {3.8755945955124474`*^9, 
   3.8755946687716208`*^9}, {3.8755947794727707`*^9, 3.875594809276833*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"f08b1df7-ea5a-49a0-b8d8-607a67abf2c8"],

Cell["\<\
Plot the forced eccentricity as a function of semi-major axis.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{3.875518167534189*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3ea90b82-6d57-423e-b1f3-e533b9fde852"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pe", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"ae1", ",", "ae2"}], "}"}], ",", " ", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.08"}], "}"}]}], "}"}]}], ",", "\n", 
    RowBox[{"Frame", "->", "True"}], ",", " ", 
    RowBox[{"Joined", "->", "True"}], ",", " ", 
    RowBox[{"AxesOrigin", "->", 
     RowBox[{"{", 
      RowBox[{"2", ",", "0"}], "}"}]}], ",", 
    RowBox[{"FrameLabel", "->", 
     RowBox[{"{", 
      RowBox[{"xlabel", ",", "y1label"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "->", 
     RowBox[{"Directive", "[", "color1", "]"}]}], ",", 
    RowBox[{"FrameStyle", "->", 
     RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
    RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.875515883641567*^9, 3.875515913009748*^9}, {
   3.875515952176573*^9, 3.875515979744947*^9}, {3.875517249567725*^9, 
   3.8755172927980003`*^9}, {3.875518200881074*^9, 3.875518221778448*^9}, 
   3.875518273138397*^9},
 CellLabel->"In[20]:=",ExpressionUUID->"a9fe61c7-c09e-462a-91f4-ec865fe9e8f3"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0V1Ik1EYB/Cd8x7BdqEFo/xqQ/CikIpKRC/mefKiZcpklvgZ5CflTZYS
5gy6EUPRKZHgZrr3fffRMmd+paWQrs8Ls3LlKkxZamLGUGFqBJHv2/nD4Vyd
P89zfrHFV7LKsEKhSNg90r2ZHKM6ghEYVW6dv3aIKn1ipVaJQF/+qYX3DlJN
/ZphVI0gubjkx7uaAXpSDoKI5Sfzwdx+esZfu/sSQfypacfL8ke00OQJHipE
MGit6Uw73kevaqVGBDcrSzrXp3upXFePYHapaMpjeUjNHVIQGNTdbqOph0pT
qNwIJgPZTlF8QJ/vtpk8CNKivsZGel1UHs+HoIxvd49HuugvqW4NQddYhSOh
+j5VyMHQW721PbHgpPJaKgx//Ru6qHwnPSwPiCEpcCwuz++gKfLCGAY2tOGL
VQ6aJdUZMHTU5fkK9jpouRwMl6IqNOZhO/3/Txi+ZXszu4rtVF7XhGHH9KGg
ab+d2qTxRAx6nSNgfW+jct0ohk5jRl9iq42+nZKCYSvp6IXR8zYqf58fw6De
1S4ctNEtad0gBmq0x936KTIPDhYz1O6VpyLz4CB9Co/faBGZBwf7Xgz/ni8V
mQcHlze91ldakXlwkB9TrViOEJkHB4bFlfDNoMA8OLCur/5xfhSYBwcTFyPN
k0MC8+CgYSTFtXNXYB4c1Cm/jHE1AvPgYKlx2nInX2AeHHhz05cytQLzINBz
+k3ijEZgHgRWw0N93UhgHgSGmuP7Nd955kEgcyZMaJrgmQeB/XOvtz9beOZB
4HZ0yOO2azzzILAnaa6xLZWnrbIHAafubFhTKM88CAROlBYdeGZlHgT052qF
kUIr8yAw6x9uyOnqZh4EUq971JqFe8yDgJKENuTMmplHCKxHN8caqiz0H2ej
dIc=
      "]]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw11X1UDWkcB/Ar3blz586deylR7E1CCimqpTBfNqHWW5xeiKizWS+7lY3U
CrEqL1utl6VwvcxMKqt07LEJIRYVwnrvWHnb5Wi952219t7b8/zOmTPn+WO+
853nc84zbnGJ4V/ZqVSqHMtlvQ+yjRqZTLR3vvEXcczddMey0Wp4N0V3VRXs
EWPyalr6xKhxITf96Z2nipg8jLsuJanRtHvI77kdFHHVk0mVplVqdJfqo2LW
yGJhgXXUOFDxVkkaIItlo62Basy6pkqY/FQSrWl5NWr0ReDhbUcl0RJmSVTD
8e/bJe22SGKzNe6JGoUTO3Yaly6JKtswSKvM0yXFSaKjLZDB5+cermUnSKKn
rSCDmavf73UVJXG4td4wBn1KNv7WfqAkhlvjJjG4dH5YhK+HJCbYhkGdNmrg
KJMkfm8LZHA0Jm7PSydJzLcVZDDwjT6r1SiJsrWexGCE4dk5f14SbXGVDEK/
zd+Twkri+XPWYVD/9sDoQrUk2rbvLoNlfMXkde0l8Y31c1ssfXJqj/jZSaKt
HqfBtsdj7yxvJ4mutg3UIFH31/WZlnWbhwZXY4yqM5Z1m4cGYcXDs/dYnm/z
0KBj0RO3d5b8Ng8N1NNNteWW97d5aDDswe6s0xqJeGjgaewW5s9JxEMD53/q
6lt46qGB06v5CXZG6qHBDcdX2ggH6qFBQadu7s1O1IPF4psD1x13oR4soldO
XdZgoh4sFppfrOnkTj1Y/FezLzvPg3qwOPvEPT+wH/VgMWD68vcOvtSDRXbO
0HHOAdSDRde00i/GBFEPFpd2+B0zg3qw2KQEnHUJoR4sVu6IWl0VJon3bB4s
Us9Hf7lkEvVgkdEjKHVGJPXQImLmkdWx06mHFn13de+6NF4S/WweWlTf97lR
OYd6aBG5JSVTSKIeWtTGFDzOWCSJtnpJWmztYP9anUE9tLgVkrVBWUk9tFha
Mah22hrqYXnf88mSx0/UQwtzwjdD2S3UQ4spcQlVH83UQ4uoLlXj7IuoB4ea
qcd8TPuoB4c6j09FY3+lHhwqEws+rjpMPTj03Hlw1eUa6sHhRJm92buOenDw
/mF4ccEl6sFhwZkjeoeb1IPD0vn9xcIm6sHBJ7yx3PsR9bDk3SxrbHhGPTgE
+lSPzHhLPTg4Gu3mBnyiHhxODzU0fmBk4qHD6RtX3OsEmXjosLx/7DXJSSYe
OozMNudkm2TiocO/Db5XUnrLxEOHU1v9IuZ5y8RDh02zjOVzA2TiocOVnRNX
LBhOzysdHKvSFq0IoeeVDs0h9/wKx8vEQ4euJ3LnHIqQiYcOvccZTt6ZIRMP
HZwyY1/ys2XiwWOJ3dlSJMrEg0f5rRO70lNl4sEjOa4xt2qZTDx4PCg291Xl
yMSDx4egtEFh+TLx4LEyUInfukUmHjyEQofvn++UiQeP12sjA0NLZOLBI+bZ
+vjiCpl48Pi5Or6Kq5KJB4/HdQuZ5BqZePDIfAamsU4mHjz2Bk1bPeYP6qFH
UIom4lAj9dCj6VhkQP8H1EMP08IlLVIz9dBjbebB2M9aqIce/lPCRha0Ug89
ypMXz+vM0P+HHrrW2aWbBYV46IGSXg3OnRXioUew28bS7a4K8dBjVFOc4N5H
IR56ZHxnf77ERyEelrWrcsh3iEI8BCTfdyuuGqEQDwGeVz/NDw5ViIeA8ovx
ty+EK8RDwPtFXEP0NIV4CIhNRZeH8QrxEBDk2piXNF8hHgJS+/nqP6YoxEPA
sT8dvs7OUIiHgNDgs4s7ZinEQ8CmalWX7bkK8bDkHblm8tisEA8Bt+VTCft3
KMRDgPPrHbWDixXiYcCczA1ux/crxMOA6hfOY0MOKcTDALtJ71zqTyjEw4BL
FwcvGF+nEA8Dfizt5XXxskI8DMjqEWya2Eg9DPAqneB14T71MOCAq79XaDP1
MEDwFD6cfE09DDAXd1sU1Eo9DHg09nT6fnUR8TCgvmf+gx5CEfEwYs1Cl/z1
TkXi/27Wo+I=
      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{2., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\\\\\\\\*TemplateBox[\
<|\\\\\\\\\\\\\\\"boxes\\\\\\\\\\\\\\\" -> FormBox[SubscriptBox[StyleBox[\\\\\
\\\\\\\\\\\"e\\\\\\\\\\\\\\\", \\\\\\\\\\\\\\\"TI\\\\\\\\\\\\\\\"], \
\\\\\\\\\\\\\\\"forced\\\\\\\\\\\\\\\"], TraditionalForm], \
\\\\\\\\\\\\\\\"errors\\\\\\\\\\\\\\\" -> {}, \\\\\\\\\\\\\\\"input\\\\\\\\\\\
\\\\\" -> \
\\\\\\\\\\\\\\\"e_{\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\rm{forced}}\\\\\\\\\\\\\\\"\
, \\\\\\\\\\\\\\\"state\\\\\\\\\\\\\\\" -> \
\\\\\\\\\\\\\\\"Boxes\\\\\\\\\\\\\\\"|>,\\\\\\\\\\\\\\\"TeXAssistantTemplate\\\
\\\\\\\\\\\\\"]\\\\\\\\)\\\\\\\"\\\", RGBColor[0.368417`, 0.506779`, \
0.709798`], Rule[StripOnInput, False]]\\)\"", HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox["\"Semi-major Axis (AU)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{2., 4.}, {0., 0.08}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8755159146702967`*^9, {3.8755159528889523`*^9, 3.875515981113369*^9}, 
   3.875517293843108*^9, {3.8755182034523907`*^9, 3.875518224663752*^9}, 
   3.875518274388036*^9, 3.875528473367528*^9, 3.8755939181873083`*^9, 
   3.875594673880989*^9, 3.875594820555457*^9, 3.875596226349534*^9, 
   3.875596383759107*^9, 3.89097673798195*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"eaac74dd-19c7-43b7-9060-b9efa4fc5820"]
}, Open  ]],

Cell["Now do the same for the forced longitudes of pericentre.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"90f8a116-4151-4f84-841e-ecbe105801ed"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pcp", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"acp1", ",", "acp2"}], "}"}], ",", " ", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "40"}], ",", "60"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Frame", "->", "True"}], ",", " ", 
    RowBox[{"Joined", "->", "True"}], ",", " ", 
    RowBox[{"AxesOrigin", "->", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "40"}]}], "}"}]}], ",", 
    RowBox[{"FrameLabel", "->", 
     RowBox[{"{", 
      RowBox[{"xlabel", ",", "y2label"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "->", 
     RowBox[{"Directive", "[", "color2", "]"}]}], ",", 
    RowBox[{"FrameStyle", "->", 
     RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
    RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.875516005427905*^9, 3.8755160528706417`*^9}, {
  3.8755161014131927`*^9, 3.875516101831129*^9}, {3.875518543378275*^9, 
  3.875518573824527*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"81f84c76-2880-4498-9d25-28120db85afc"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.009166666666666668], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw903tIU1EcB/B777kMsbSHq7Y5dXOWy6bmc+bz5wM0KsxHRTmyjCIrNYdo
04qKNilFHVpmmbhmYGpGEPgox3H+kWnmSkglKkSpyCR7WFGu2r0d+sHl/HP4
nu+PD1eeU5B+kKEoKtzxcafJoLukfkIBxU8SnioVdiZPUVAsrCo8F5WIvyk1
1dYFCv5kVMwPFyRg53Hz8RhnGnJeo8wd7fHYSz+b1u1Jg/xKXe2POcAh/NCw
YrvudKUacAofSMO00r55aFkc5tKUGhru+ymaWvticGEMl0hD03jzfMaJaMzH
6WlIyuuoz42LwlcbuKEhTq9U61dGYkc5RyANo0E9zfGfIvDAAleQhu7k26ZN
L9SYrzdOw6OJmQdOtnD8gYubpUFoDrZtGQ3D//Zk4Jat66ZpIhQL+UAGxPPF
2vbZELyeL8jAEsV0ootTCI7lF3bcT6/Zm+8fjNO5uDQGnJ4dq9FlBeFD/DAg
sHvqXho34jI+kAHvufrLDc2BmF+3mgHJUq2bXRWAW7h6ZgaMiVMGzaAK83Hd
DJR5W1sitBvwyGNuGPgddhekfn7Ew/Feq3Wu8aOSeDCQGdBvybL6Eg8EhunY
UMGNdcQDwVhvau6uqrXEA0Hgqpk6cbkP8UCwvL5/0bdSQTwQDGc8PVt43Zt4
IPDQJi/+6pUTDwSKsTv33s3IiAeC3Z2ph0vdZcQDgatr39dIiyfxQNDhEm14
s8+DeCCwtAgnB2RS4oEgf7UxZSflTjxY2PMziZIgCfFgoS1BU/XWX0w8WBCI
BNsqykXEgwW3qO/GLrGIeLDwpUSTV/d5DfFg4aR9VF7kKyIeLFiHj0oGJ0W4
hvdgQXrk4cVXICEeLGw9kGoesUiJBwvZXpOndBdkxIOFHpCpTEU+xIOFayWN
5y0FKuLBwpm27P3vn0fgoQV9LrXI/v+f/gJOrHjz
      "]]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.009166666666666668], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0XtQjXkcx/GKc3vOc86pLad75/48z8m0WHIvnwxFsUmrQlGsyxp0cZdl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      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{2., -40.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\\\\\\\\*TemplateBox[\
<|\\\\\\\\\\\\\\\"boxes\\\\\\\\\\\\\\\" -> \
FormBox[RowBox[{SubscriptBox[\\\\\\\\\\\\\\\"\[CurlyPi]\\\\\\\\\\\\\\\", \\\\\
\\\\\\\\\\\"forced\\\\\\\\\\\\\\\"], \\\\\\\\\\\\\\\" \\\\\\\\\\\\\\\", \
RowBox[{\\\\\\\\\\\\\\\"(\\\\\\\\\\\\\\\", \\\\\\\\\\\\\\\"deg.\\\\\\\\\\\\\\\
\", \\\\\\\\\\\\\\\")\\\\\\\\\\\\\\\"}]}], TraditionalForm], \
\\\\\\\\\\\\\\\"errors\\\\\\\\\\\\\\\" -> {}, \\\\\\\\\\\\\\\"input\\\\\\\\\\\
\\\\\" -> \\\\\\\\\\\\\\\"\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\varpi_{\\\\\\\\\\\\\
\\\\\\\\\\\\\\\\\\\\rm{forced}}\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\,(\\\\\\\\\\\\\
\\\\\\\\\\\\\\\\\\\\rm{deg.})\\\\\\\\\\\\\\\", \
\\\\\\\\\\\\\\\"state\\\\\\\\\\\\\\\" -> \
\\\\\\\\\\\\\\\"Boxes\\\\\\\\\\\\\\\"|>,\\\\\\\\\\\\\\\"TeXAssistantTemplate\\\
\\\\\\\\\\\\\"]\\\\\\\\)\\\\\\\"\\\", RGBColor[0.880722`, 0.611041`, \
0.142051`], Rule[StripOnInput, False]]\\)\"", HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox["\"Semi-major Axis (AU)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{2., 4.}, {-40., 60.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.87551604572362*^9, 3.875516053942638*^9}, 
   3.875516102857452*^9, {3.875518561361964*^9, 3.875518575154813*^9}, 
   3.875528490537633*^9, {3.875528954809945*^9, 3.875528975489732*^9}, 
   3.875593926383963*^9, 3.875594681966485*^9, 3.875594823962016*^9, 
   3.875596226447076*^9, 3.875596383845748*^9, 3.890976738047174*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"4f3276d7-7629-40bf-8d3f-14f69ded6366"]
}, Open  ]],

Cell[TextData[{
 "Load ",
 StyleBox["CombinePlots",
  FontWeight->"Bold"],
 " function available as a Resource Function. (See \
https://resources.wolframcloud.com/FunctionRepository/resources/CombinePlots/?\
i=CombinePlots&searchapi=https%3A%2F%2Fresources.wolframcloud.com%\
2FFunctionRepository%2Fsearch).  This will be used later on to combine two \
plots with different vertical axes."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.87552830525301*^9, 3.875528337502783*^9}, {
  3.875528367952729*^9, 3.875528404583641*^9}, {3.875593450917975*^9, 
  3.8755934696222*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"cc462445-6811-44f2-8ec9-9691bf8635a7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cp", "=", 
   RowBox[{"ResourceFunction", "[", "\"\<CombinePlots\>\"", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.875526995580248*^9, 3.875526995594998*^9}, {
  3.875527360455002*^9, 3.875527361233553*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"664c68d9-b11d-4547-be01-b8336599da82"],

Cell[TextData[{
 "Now combine the two plots using the ",
 StyleBox["cp",
  FontWeight->"Bold"],
 " function."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.875594014337295*^9, 3.875594029382044*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6f81f977-e643-46cc-8f67-837cfed3d32d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cp", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ae1", ",", "ae2"}], "}"}], ",", " ", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0.08"}], "}"}]}], "}"}]}], ",", "\n", 
     RowBox[{"Frame", "->", "True"}], ",", " ", 
     RowBox[{"Joined", "->", "True"}], ",", " ", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "y1label"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"Directive", "[", "color1", "]"}]}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"acp1", ",", "acp2"}], "}"}], ",", " ", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "40"}], ",", "60"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", " ", 
     RowBox[{"Joined", "->", "True"}], ",", " ", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"2", ",", 
        RowBox[{"-", "40"}]}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "y2label"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"Directive", "[", "color2", "]"}]}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}], ",", 
   RowBox[{"\"\<AxesSides\>\"", "->", "\"\<TwoY\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.875528457130026*^9, 3.875528516905005*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"2a6d126d-d350-4cbb-8709-61f7f414155a"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0V1Ik1EYB/Cd8x7BdqEFo/xqQ/CikIpKRC/mefKiZcpklvgZ5CflTZYS
5gy6EUPRKZHgZrr3fffRMmd+paWQrs8Ls3LlKkxZamLGUGFqBJHv2/nD4Vyd
P89zfrHFV7LKsEKhSNg90r2ZHKM6ghEYVW6dv3aIKn1ipVaJQF/+qYX3DlJN
/ZphVI0gubjkx7uaAXpSDoKI5Sfzwdx+esZfu/sSQfypacfL8ke00OQJHipE
MGit6Uw73kevaqVGBDcrSzrXp3upXFePYHapaMpjeUjNHVIQGNTdbqOph0pT
qNwIJgPZTlF8QJ/vtpk8CNKivsZGel1UHs+HoIxvd49HuugvqW4NQddYhSOh
+j5VyMHQW721PbHgpPJaKgx//Ru6qHwnPSwPiCEpcCwuz++gKfLCGAY2tOGL
VQ6aJdUZMHTU5fkK9jpouRwMl6IqNOZhO/3/Txi+ZXszu4rtVF7XhGHH9KGg
ab+d2qTxRAx6nSNgfW+jct0ohk5jRl9iq42+nZKCYSvp6IXR8zYqf58fw6De
1S4ctNEtad0gBmq0x936KTIPDhYz1O6VpyLz4CB9Co/faBGZBwf7Xgz/ni8V
mQcHlze91ldakXlwkB9TrViOEJkHB4bFlfDNoMA8OLCur/5xfhSYBwcTFyPN
k0MC8+CgYSTFtXNXYB4c1Cm/jHE1AvPgYKlx2nInX2AeHHhz05cytQLzINBz
+k3ijEZgHgRWw0N93UhgHgSGmuP7Nd955kEgcyZMaJrgmQeB/XOvtz9beOZB
4HZ0yOO2azzzILAnaa6xLZWnrbIHAafubFhTKM88CAROlBYdeGZlHgT052qF
kUIr8yAw6x9uyOnqZh4EUq971JqFe8yDgJKENuTMmplHCKxHN8caqiz0H2ej
dIc=
       "]]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw11X1UDWkcB/Ar3blz586deylR7E1CCimqpTBfNqHWW5xeiKizWS+7lY3U
CrEqL1utl6VwvcxMKqt07LEJIRYVwnrvWHnb5Wi952219t7b8/zOmTPn+WO+
853nc84zbnGJ4V/ZqVSqHMtlvQ+yjRqZTLR3vvEXcczddMey0Wp4N0V3VRXs
EWPyalr6xKhxITf96Z2nipg8jLsuJanRtHvI77kdFHHVk0mVplVqdJfqo2LW
yGJhgXXUOFDxVkkaIItlo62Basy6pkqY/FQSrWl5NWr0ReDhbUcl0RJmSVTD
8e/bJe22SGKzNe6JGoUTO3Yaly6JKtswSKvM0yXFSaKjLZDB5+cermUnSKKn
rSCDmavf73UVJXG4td4wBn1KNv7WfqAkhlvjJjG4dH5YhK+HJCbYhkGdNmrg
KJMkfm8LZHA0Jm7PSydJzLcVZDDwjT6r1SiJsrWexGCE4dk5f14SbXGVDEK/
zd+Twkri+XPWYVD/9sDoQrUk2rbvLoNlfMXkde0l8Y31c1ssfXJqj/jZSaKt
HqfBtsdj7yxvJ4mutg3UIFH31/WZlnWbhwZXY4yqM5Z1m4cGYcXDs/dYnm/z
0KBj0RO3d5b8Ng8N1NNNteWW97d5aDDswe6s0xqJeGjgaewW5s9JxEMD53/q
6lt46qGB06v5CXZG6qHBDcdX2ggH6qFBQadu7s1O1IPF4psD1x13oR4soldO
XdZgoh4sFppfrOnkTj1Y/FezLzvPg3qwOPvEPT+wH/VgMWD68vcOvtSDRXbO
0HHOAdSDRde00i/GBFEPFpd2+B0zg3qw2KQEnHUJoR4sVu6IWl0VJon3bB4s
Us9Hf7lkEvVgkdEjKHVGJPXQImLmkdWx06mHFn13de+6NF4S/WweWlTf97lR
OYd6aBG5JSVTSKIeWtTGFDzOWCSJtnpJWmztYP9anUE9tLgVkrVBWUk9tFha
Mah22hrqYXnf88mSx0/UQwtzwjdD2S3UQ4spcQlVH83UQ4uoLlXj7IuoB4ea
qcd8TPuoB4c6j09FY3+lHhwqEws+rjpMPTj03Hlw1eUa6sHhRJm92buOenDw
/mF4ccEl6sFhwZkjeoeb1IPD0vn9xcIm6sHBJ7yx3PsR9bDk3SxrbHhGPTgE
+lSPzHhLPTg4Gu3mBnyiHhxODzU0fmBk4qHD6RtX3OsEmXjosLx/7DXJSSYe
OozMNudkm2TiocO/Db5XUnrLxEOHU1v9IuZ5y8RDh02zjOVzA2TiocOVnRNX
LBhOzysdHKvSFq0IoeeVDs0h9/wKx8vEQ4euJ3LnHIqQiYcOvccZTt6ZIRMP
HZwyY1/ys2XiwWOJ3dlSJMrEg0f5rRO70lNl4sEjOa4xt2qZTDx4PCg291Xl
yMSDx4egtEFh+TLx4LEyUInfukUmHjyEQofvn++UiQeP12sjA0NLZOLBI+bZ
+vjiCpl48Pi5Or6Kq5KJB4/HdQuZ5BqZePDIfAamsU4mHjz2Bk1bPeYP6qFH
UIom4lAj9dCj6VhkQP8H1EMP08IlLVIz9dBjbebB2M9aqIce/lPCRha0Ug89
ypMXz+vM0P+HHrrW2aWbBYV46IGSXg3OnRXioUew28bS7a4K8dBjVFOc4N5H
IR56ZHxnf77ERyEelrWrcsh3iEI8BCTfdyuuGqEQDwGeVz/NDw5ViIeA8ovx
ty+EK8RDwPtFXEP0NIV4CIhNRZeH8QrxEBDk2piXNF8hHgJS+/nqP6YoxEPA
sT8dvs7OUIiHgNDgs4s7ZinEQ8CmalWX7bkK8bDkHblm8tisEA8Bt+VTCft3
KMRDgPPrHbWDixXiYcCczA1ux/crxMOA6hfOY0MOKcTDALtJ71zqTyjEw4BL
FwcvGF+nEA8Dfizt5XXxskI8DMjqEWya2Eg9DPAqneB14T71MOCAq79XaDP1
MEDwFD6cfE09DDAXd1sU1Eo9DHg09nT6fnUR8TCgvmf+gx5CEfEwYs1Cl/z1
TkXi/27Wo+I=
       "]]}}, {{}, {}}}, GeometricTransformationBox[{{}, {{}, {}, 
      {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
       0.009166666666666668], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJw903tIU1EcB/B777kMsbSHq7Y5dXOWy6bmc+bz5wM0KsxHRTmyjCIrNYdo
04qKNilFHVpmmbhmYGpGEPgox3H+kWnmSkglKkSpyCR7WFGu2r0d+sHl/HP4
nu+PD1eeU5B+kKEoKtzxcafJoLukfkIBxU8SnioVdiZPUVAsrCo8F5WIvyk1
1dYFCv5kVMwPFyRg53Hz8RhnGnJeo8wd7fHYSz+b1u1Jg/xKXe2POcAh/NCw
YrvudKUacAofSMO00r55aFkc5tKUGhru+ymaWvticGEMl0hD03jzfMaJaMzH
6WlIyuuoz42LwlcbuKEhTq9U61dGYkc5RyANo0E9zfGfIvDAAleQhu7k26ZN
L9SYrzdOw6OJmQdOtnD8gYubpUFoDrZtGQ3D//Zk4Jat66ZpIhQL+UAGxPPF
2vbZELyeL8jAEsV0ootTCI7lF3bcT6/Zm+8fjNO5uDQGnJ4dq9FlBeFD/DAg
sHvqXho34jI+kAHvufrLDc2BmF+3mgHJUq2bXRWAW7h6ZgaMiVMGzaAK83Hd
DJR5W1sitBvwyGNuGPgddhekfn7Ew/Feq3Wu8aOSeDCQGdBvybL6Eg8EhunY
UMGNdcQDwVhvau6uqrXEA0Hgqpk6cbkP8UCwvL5/0bdSQTwQDGc8PVt43Zt4
IPDQJi/+6pUTDwSKsTv33s3IiAeC3Z2ph0vdZcQDgatr39dIiyfxQNDhEm14
s8+DeCCwtAgnB2RS4oEgf7UxZSflTjxY2PMziZIgCfFgoS1BU/XWX0w8WBCI
BNsqykXEgwW3qO/GLrGIeLDwpUSTV/d5DfFg4aR9VF7kKyIeLFiHj0oGJ0W4
hvdgQXrk4cVXICEeLGw9kGoesUiJBwvZXpOndBdkxIOFHpCpTEU+xIOFayWN
5y0FKuLBwpm27P3vn0fgoQV9LrXI/v+f/gJOrHjz
        "]]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
       0.009166666666666668], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJwt0XtQjXkcx/GKc3vOc86pLad75/48z8m0WHIvnwxFsUmrQlGsyxp0cZdl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        "]]}}, {{}, {}}}, {{{1., 0.}, {0., 0.0008}}, {0., 0.032}}], 
   GeometricTransformationBox[{}, {{{1., 0.}, {0., 0.0008}}, {0., 0.032}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{2., 0.},
  CoordinatesToolOptions:>{"CopiedValueFunction" -> Apply[{{Bottom, Left} -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& )[{#, #2}], {Bottom, Right} -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& )[{#, -40. + 1250. #2}]}& ], "DisplayFunction" -> 
    Apply[Grid[{{
         Row[{
           Style["\[LeftArrow]", 20], " ", 
           ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )[{#, #2}]}]}, {
         Row[{
           ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )[{#, -40. + 1250. #2}], " ", 
           Style["\[RightArrow]", 20]}]}}, Dividers -> Center, FrameStyle -> 
       Thickness[Large], Spacings -> 2]& ]},
  DisplayFunction->Identity,
  Epilog->{{}, 
    GeometricTransformationBox[{}, {{{1., 0.}, {0., 0.0008}}, {0., 0.032}}]},
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\\\\\\\\*TemplateBox[\
<|\\\\\\\\\\\\\\\"boxes\\\\\\\\\\\\\\\" -> FormBox[SubscriptBox[StyleBox[\\\\\
\\\\\\\\\\\"e\\\\\\\\\\\\\\\", \\\\\\\\\\\\\\\"TI\\\\\\\\\\\\\\\"], \
\\\\\\\\\\\\\\\"forced\\\\\\\\\\\\\\\"], TraditionalForm], \
\\\\\\\\\\\\\\\"errors\\\\\\\\\\\\\\\" -> {}, \\\\\\\\\\\\\\\"input\\\\\\\\\\\
\\\\\" -> \
\\\\\\\\\\\\\\\"e_{\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\rm{forced}}\\\\\\\\\\\\\\\"\
, \\\\\\\\\\\\\\\"state\\\\\\\\\\\\\\\" -> \
\\\\\\\\\\\\\\\"Boxes\\\\\\\\\\\\\\\"|>,\\\\\\\\\\\\\\\"TeXAssistantTemplate\\\
\\\\\\\\\\\\\"]\\\\\\\\)\\\\\\\"\\\", RGBColor[0.368417`, 0.506779`, \
0.709798`], Rule[StripOnInput, False]]\\)\"", HoldForm], TraditionalForm], 
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\\\\\\\\*TemplateBox[\
<|\\\\\\\\\\\\\\\"boxes\\\\\\\\\\\\\\\" -> \
FormBox[RowBox[{SubscriptBox[\\\\\\\\\\\\\\\"\[CurlyPi]\\\\\\\\\\\\\\\", \\\\\
\\\\\\\\\\\"forced\\\\\\\\\\\\\\\"], \\\\\\\\\\\\\\\" \\\\\\\\\\\\\\\", \
RowBox[{\\\\\\\\\\\\\\\"(\\\\\\\\\\\\\\\", \\\\\\\\\\\\\\\"deg.\\\\\\\\\\\\\\\
\", \\\\\\\\\\\\\\\")\\\\\\\\\\\\\\\"}]}], TraditionalForm], \
\\\\\\\\\\\\\\\"errors\\\\\\\\\\\\\\\" -> {}, \\\\\\\\\\\\\\\"input\\\\\\\\\\\
\\\\\" -> \\\\\\\\\\\\\\\"\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\varpi_{\\\\\\\\\\\\\
\\\\\\\\\\\\\\\\\\\\rm{forced}}\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\,(\\\\\\\\\\\\\
\\\\\\\\\\\\\\\\\\\\rm{deg.})\\\\\\\\\\\\\\\", \
\\\\\\\\\\\\\\\"state\\\\\\\\\\\\\\\" -> \
\\\\\\\\\\\\\\\"Boxes\\\\\\\\\\\\\\\"|>,\\\\\\\\\\\\\\\"TeXAssistantTemplate\\\
\\\\\\\\\\\\\"]\\\\\\\\)\\\\\\\"\\\", RGBColor[0.880722`, 0.611041`, \
0.142051`], Rule[StripOnInput, False]]\\)\"", HoldForm], TraditionalForm]}, {
     FormBox[
      TagBox["\"Semi-major Axis (AU)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->{{
     Thickness[0.004], 
     Thickness[0.004]}, {
     Thickness[0.004], 
     Thickness[0.004]}},
  FrameTicks->FrontEndValueCache[{{ResourceFunction["CombinePlots"][
       "CustomTicks"[True]][
       SlotSequence[1]]& , {{0., 
        FormBox[
        "\"\\!\\(\\*FormBox[RowBox[{\\\"-\\\", \\\"40\\\"}], TraditionalForm]\
\\)\"", TraditionalForm], {0.01, 0.}}, {0.016, 
        FormBox[
        "\"\\!\\(\\*FormBox[RowBox[{\\\"-\\\", \\\"20\\\"}], TraditionalForm]\
\\)\"", TraditionalForm], {0.01, 0.}}, {0.032, 
        FormBox[
        "\"\\!\\(\\*FormBox[\\\"0\\\", TraditionalForm]\\)\"", 
         TraditionalForm], {0.01, 0.}}, {0.048, 
        FormBox[
        "\"\\!\\(\\*FormBox[\\\"20\\\", TraditionalForm]\\)\"", 
         TraditionalForm], {0.01, 0.}}, {0.064, 
        FormBox[
        "\"\\!\\(\\*FormBox[\\\"40\\\", TraditionalForm]\\)\"", 
         TraditionalForm], {0.01, 0.}}, {0.08, 
        FormBox[
        "\"\\!\\(\\*FormBox[\\\"60\\\", TraditionalForm]\\)\"", 
         TraditionalForm], {0.01, 0.}}, {0.004, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.008, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.012, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.02, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.024, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.028, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.036000000000000004`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.04, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.044, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.052000000000000005`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.056, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.06, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.068, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.07200000000000001, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.07600000000000001, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}}}, {
     ResourceFunction["CombinePlots"][
       "CustomTicks"[True]][
       SlotSequence[1]]& , ResourceFunction["CombinePlots"][
       "CustomTicks"[False]][
       SlotSequence[1]]& }}, {{{{0., 
        FormBox[
        "\"\\!\\(\\*FormBox[\\\"0\\\", TraditionalForm]\\)\"", 
         TraditionalForm], {0.01, 0.}}, {0.02, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"0.\
02\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 0.02`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 2]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {0.04, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"0.\
04\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 0.04`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 2]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {0.06, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"0.\
06\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 0.06`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 2]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {0.08, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"0.\
08\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 0.08`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 2]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {0.005, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.01, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.015, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.025, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.03, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.035, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.045, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.05, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.055, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.065, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.07, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.075, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}}, {{
       0., 
        FormBox[
        "\"\\!\\(\\*FormBox[RowBox[{\\\"-\\\", \\\"40\\\"}], TraditionalForm]\
\\)\"", TraditionalForm], {0.01, 0.}}, {0.016, 
        FormBox[
        "\"\\!\\(\\*FormBox[RowBox[{\\\"-\\\", \\\"20\\\"}], TraditionalForm]\
\\)\"", TraditionalForm], {0.01, 0.}}, {0.032, 
        FormBox[
        "\"\\!\\(\\*FormBox[\\\"0\\\", TraditionalForm]\\)\"", 
         TraditionalForm], {0.01, 0.}}, {0.048, 
        FormBox[
        "\"\\!\\(\\*FormBox[\\\"20\\\", TraditionalForm]\\)\"", 
         TraditionalForm], {0.01, 0.}}, {0.064, 
        FormBox[
        "\"\\!\\(\\*FormBox[\\\"40\\\", TraditionalForm]\\)\"", 
         TraditionalForm], {0.01, 0.}}, {0.08, 
        FormBox[
        "\"\\!\\(\\*FormBox[\\\"60\\\", TraditionalForm]\\)\"", 
         TraditionalForm], {0.01, 0.}}, {0.004, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.008, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.012, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.02, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.024, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.028, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.036000000000000004`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.04, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.044, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.052000000000000005`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.056, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.06, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.068, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.07200000000000001, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.07600000000000001, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}}}, {{{
       2., 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"2.0\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 2.`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {2.5, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"2.5\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 2.5`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {3., 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"3.0\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 3.`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {3.5, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"3.5\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 3.5`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {4., 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"4.0\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 4.`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {2.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}}, {{
       2., 
        FormBox[
         TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.01, 0.}}, {2.5, 
        FormBox[
         TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.01, 0.}}, {3., 
        FormBox[
         TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.01, 0.}}, {3.5, 
        FormBox[
         TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.01, 0.}}, {4., 
        FormBox[
         TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.01, 0.}}, {2.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}}}}],
  FrameTicksStyle->{{None, None}, {None, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True},
  PlotRange->{{2., 4.}, {0., 0.08}},
  PlotRangeClipping->True,
  PlotRangePadding->None,
  Prolog->{{}, 
    GeometricTransformationBox[{}, {{{1., 0.}, {0., 0.0008}}, {0., 0.032}}]},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.875528522520068*^9, 3.8755289857729673`*^9, 3.8755940440061398`*^9, {
   3.8755941911382723`*^9, 3.8755942287687407`*^9}, 3.875594687711725*^9, 
   3.8755948292634077`*^9, 3.875596227347784*^9, 3.875596384761539*^9, 
   3.89097674126577*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"23939e7d-d05f-4c05-8d95-0f454f821a00"]
}, Open  ]],

Cell[TextData[{
 "Now combine the two plots using the ",
 StyleBox["cp",
  FontWeight->"Bold"],
 " function but using a dashed curve to denote the forced longitude of \
pericentre.  This gives Fig.7.16a."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.875594014337295*^9, 3.875594029382044*^9}, {
  3.875595845002529*^9, 3.875595899693761*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f699bdf6-1fb5-4c96-9174-ed7965eefb71"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cp", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ae1", ",", "ae2"}], "}"}], ",", " ", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0.08"}], "}"}]}], "}"}]}], ",", "\n", 
     RowBox[{"Frame", "->", "True"}], ",", " ", 
     RowBox[{"Joined", "->", "True"}], ",", " ", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "->", "color1"}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "y1labelplain"}], "}"}]}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"acp1", ",", "acp2"}], "}"}], ",", " ", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "40"}], ",", "60"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", " ", 
     RowBox[{"Joined", "->", "True"}], ",", " ", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"2", ",", 
        RowBox[{"-", "40"}]}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "y2labelplain"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"color1", ",", "Dashed"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"color1", ",", "Dashed"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}], ",", 
   RowBox[{"\"\<AxesSides\>\"", "->", "\"\<TwoY\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.875528457130026*^9, 3.875528516905005*^9}, {
   3.875594838826838*^9, 3.8755948502414827`*^9}, {3.8755948918972683`*^9, 
   3.875594892677314*^9}, {3.875594943227437*^9, 3.87559494426163*^9}, 
   3.875595034369237*^9, {3.8755950983152523`*^9, 3.8755952006151857`*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"590b9f51-d578-48e3-99d5-eccf40044674"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0V1Ik1EYB/Cd8x7BdqEFo/xqQ/CikIpKRC/mefKiZcpklvgZ5CflTZYS
5gy6EUPRKZHgZrr3fffRMmd+paWQrs8Ls3LlKkxZamLGUGFqBJHv2/nD4Vyd
P89zfrHFV7LKsEKhSNg90r2ZHKM6ghEYVW6dv3aIKn1ipVaJQF/+qYX3DlJN
/ZphVI0gubjkx7uaAXpSDoKI5Sfzwdx+esZfu/sSQfypacfL8ke00OQJHipE
MGit6Uw73kevaqVGBDcrSzrXp3upXFePYHapaMpjeUjNHVIQGNTdbqOph0pT
qNwIJgPZTlF8QJ/vtpk8CNKivsZGel1UHs+HoIxvd49HuugvqW4NQddYhSOh
+j5VyMHQW721PbHgpPJaKgx//Ru6qHwnPSwPiCEpcCwuz++gKfLCGAY2tOGL
VQ6aJdUZMHTU5fkK9jpouRwMl6IqNOZhO/3/Txi+ZXszu4rtVF7XhGHH9KGg
ab+d2qTxRAx6nSNgfW+jct0ohk5jRl9iq42+nZKCYSvp6IXR8zYqf58fw6De
1S4ctNEtad0gBmq0x936KTIPDhYz1O6VpyLz4CB9Co/faBGZBwf7Xgz/ni8V
mQcHlze91ldakXlwkB9TrViOEJkHB4bFlfDNoMA8OLCur/5xfhSYBwcTFyPN
k0MC8+CgYSTFtXNXYB4c1Cm/jHE1AvPgYKlx2nInX2AeHHhz05cytQLzINBz
+k3ijEZgHgRWw0N93UhgHgSGmuP7Nd955kEgcyZMaJrgmQeB/XOvtz9beOZB
4HZ0yOO2azzzILAnaa6xLZWnrbIHAafubFhTKM88CAROlBYdeGZlHgT052qF
kUIr8yAw6x9uyOnqZh4EUq971JqFe8yDgJKENuTMmplHCKxHN8caqiz0H2ej
dIc=
       "]]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw11X1UDWkcB/Ar3blz586deylR7E1CCimqpTBfNqHWW5xeiKizWS+7lY3U
CrEqL1utl6VwvcxMKqt07LEJIRYVwnrvWHnb5Wi952219t7b8/zOmTPn+WO+
853nc84zbnGJ4V/ZqVSqHMtlvQ+yjRqZTLR3vvEXcczddMey0Wp4N0V3VRXs
EWPyalr6xKhxITf96Z2nipg8jLsuJanRtHvI77kdFHHVk0mVplVqdJfqo2LW
yGJhgXXUOFDxVkkaIItlo62Basy6pkqY/FQSrWl5NWr0ReDhbUcl0RJmSVTD
8e/bJe22SGKzNe6JGoUTO3Yaly6JKtswSKvM0yXFSaKjLZDB5+cermUnSKKn
rSCDmavf73UVJXG4td4wBn1KNv7WfqAkhlvjJjG4dH5YhK+HJCbYhkGdNmrg
KJMkfm8LZHA0Jm7PSydJzLcVZDDwjT6r1SiJsrWexGCE4dk5f14SbXGVDEK/
zd+Twkri+XPWYVD/9sDoQrUk2rbvLoNlfMXkde0l8Y31c1ssfXJqj/jZSaKt
HqfBtsdj7yxvJ4mutg3UIFH31/WZlnWbhwZXY4yqM5Z1m4cGYcXDs/dYnm/z
0KBj0RO3d5b8Ng8N1NNNteWW97d5aDDswe6s0xqJeGjgaewW5s9JxEMD53/q
6lt46qGB06v5CXZG6qHBDcdX2ggH6qFBQadu7s1O1IPF4psD1x13oR4soldO
XdZgoh4sFppfrOnkTj1Y/FezLzvPg3qwOPvEPT+wH/VgMWD68vcOvtSDRXbO
0HHOAdSDRde00i/GBFEPFpd2+B0zg3qw2KQEnHUJoR4sVu6IWl0VJon3bB4s
Us9Hf7lkEvVgkdEjKHVGJPXQImLmkdWx06mHFn13de+6NF4S/WweWlTf97lR
OYd6aBG5JSVTSKIeWtTGFDzOWCSJtnpJWmztYP9anUE9tLgVkrVBWUk9tFha
Mah22hrqYXnf88mSx0/UQwtzwjdD2S3UQ4spcQlVH83UQ4uoLlXj7IuoB4ea
qcd8TPuoB4c6j09FY3+lHhwqEws+rjpMPTj03Hlw1eUa6sHhRJm92buOenDw
/mF4ccEl6sFhwZkjeoeb1IPD0vn9xcIm6sHBJ7yx3PsR9bDk3SxrbHhGPTgE
+lSPzHhLPTg4Gu3mBnyiHhxODzU0fmBk4qHD6RtX3OsEmXjosLx/7DXJSSYe
OozMNudkm2TiocO/Db5XUnrLxEOHU1v9IuZ5y8RDh02zjOVzA2TiocOVnRNX
LBhOzysdHKvSFq0IoeeVDs0h9/wKx8vEQ4euJ3LnHIqQiYcOvccZTt6ZIRMP
HZwyY1/ys2XiwWOJ3dlSJMrEg0f5rRO70lNl4sEjOa4xt2qZTDx4PCg291Xl
yMSDx4egtEFh+TLx4LEyUInfukUmHjyEQofvn++UiQeP12sjA0NLZOLBI+bZ
+vjiCpl48Pi5Or6Kq5KJB4/HdQuZ5BqZePDIfAamsU4mHjz2Bk1bPeYP6qFH
UIom4lAj9dCj6VhkQP8H1EMP08IlLVIz9dBjbebB2M9aqIce/lPCRha0Ug89
ypMXz+vM0P+HHrrW2aWbBYV46IGSXg3OnRXioUew28bS7a4K8dBjVFOc4N5H
IR56ZHxnf77ERyEelrWrcsh3iEI8BCTfdyuuGqEQDwGeVz/NDw5ViIeA8ovx
ty+EK8RDwPtFXEP0NIV4CIhNRZeH8QrxEBDk2piXNF8hHgJS+/nqP6YoxEPA
sT8dvs7OUIiHgNDgs4s7ZinEQ8CmalWX7bkK8bDkHblm8tisEA8Bt+VTCft3
KMRDgPPrHbWDixXiYcCczA1ux/crxMOA6hfOY0MOKcTDALtJ71zqTyjEw4BL
FwcvGF+nEA8Dfizt5XXxskI8DMjqEWya2Eg9DPAqneB14T71MOCAq79XaDP1
MEDwFD6cfE09DDAXd1sU1Eo9DHg09nT6fnUR8TCgvmf+gx5CEfEwYs1Cl/z1
TkXi/27Wo+I=
       "]]}}, {{}, {}}}, GeometricTransformationBox[{{}, {{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.009166666666666668], AbsoluteThickness[1.6], Dashing[{Small, Small}],
        LineBox[CompressedData["
1:eJw903tIU1EcB/B777kMsbSHq7Y5dXOWy6bmc+bz5wM0KsxHRTmyjCIrNYdo
04qKNilFHVpmmbhmYGpGEPgox3H+kWnmSkglKkSpyCR7WFGu2r0d+sHl/HP4
nu+PD1eeU5B+kKEoKtzxcafJoLukfkIBxU8SnioVdiZPUVAsrCo8F5WIvyk1
1dYFCv5kVMwPFyRg53Hz8RhnGnJeo8wd7fHYSz+b1u1Jg/xKXe2POcAh/NCw
YrvudKUacAofSMO00r55aFkc5tKUGhru+ymaWvticGEMl0hD03jzfMaJaMzH
6WlIyuuoz42LwlcbuKEhTq9U61dGYkc5RyANo0E9zfGfIvDAAleQhu7k26ZN
L9SYrzdOw6OJmQdOtnD8gYubpUFoDrZtGQ3D//Zk4Jat66ZpIhQL+UAGxPPF
2vbZELyeL8jAEsV0ootTCI7lF3bcT6/Zm+8fjNO5uDQGnJ4dq9FlBeFD/DAg
sHvqXho34jI+kAHvufrLDc2BmF+3mgHJUq2bXRWAW7h6ZgaMiVMGzaAK83Hd
DJR5W1sitBvwyGNuGPgddhekfn7Ew/Feq3Wu8aOSeDCQGdBvybL6Eg8EhunY
UMGNdcQDwVhvau6uqrXEA0Hgqpk6cbkP8UCwvL5/0bdSQTwQDGc8PVt43Zt4
IPDQJi/+6pUTDwSKsTv33s3IiAeC3Z2ph0vdZcQDgatr39dIiyfxQNDhEm14
s8+DeCCwtAgnB2RS4oEgf7UxZSflTjxY2PMziZIgCfFgoS1BU/XWX0w8WBCI
BNsqykXEgwW3qO/GLrGIeLDwpUSTV/d5DfFg4aR9VF7kKyIeLFiHj0oGJ0W4
hvdgQXrk4cVXICEeLGw9kGoesUiJBwvZXpOndBdkxIOFHpCpTEU+xIOFayWN
5y0FKuLBwpm27P3vn0fgoQV9LrXI/v+f/gJOrHjz
        "]]}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.009166666666666668], AbsoluteThickness[1.6], Dashing[{Small, Small}],
        LineBox[CompressedData["
1:eJwt0XtQjXkcx/GKc3vOc86pLad75/48z8m0WHIvnwxFsUmrQlGsyxp0cZdl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        "]]}}, {{}, {}}}, {{{1., 0.}, {0., 0.0008}}, {0., 0.032}}], 
   GeometricTransformationBox[{}, {{{1., 0.}, {0., 0.0008}}, {0., 0.032}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{2., 0.},
  CoordinatesToolOptions:>{"CopiedValueFunction" -> Apply[{{Bottom, Left} -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& )[{#, #2}], {Bottom, Right} -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& )[{#, -40. + 1250. #2}]}& ], "DisplayFunction" -> 
    Apply[Grid[{{
         Row[{
           Style["\[LeftArrow]", 20], " ", 
           ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )[{#, #2}]}]}, {
         Row[{
           ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )[{#, -40. + 1250. #2}], " ", 
           Style["\[RightArrow]", 20]}]}}, Dividers -> Center, FrameStyle -> 
       Thickness[Large], Spacings -> 2]& ]},
  DisplayFunction->Identity,
  Epilog->{{}, 
    GeometricTransformationBox[{}, {{{1., 0.}, {0., 0.0008}}, {0., 0.032}}]},
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[SubscriptBox[StyleBox[\\\"e\\\", \\\"TI\\\"], \\\"forced\\\"], \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"e_{\\\\\\\\rm{forced}}\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", HoldForm], 
      TraditionalForm], 
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[RowBox[{SubscriptBox[\\\"\[CurlyPi]\\\", \\\"forced\\\"], \\\" \\\", \
RowBox[{\\\"(\\\", \\\"deg.\\\", \\\")\\\"}]}], TraditionalForm], \
\\\"errors\\\" -> {}, \\\"input\\\" -> \\\"\\\\\\\\varpi_{\\\\\\\\rm{forced}}\
\\\\\\\\,(\\\\\\\\rm{deg.})\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", HoldForm], 
      TraditionalForm]}, {
     FormBox[
      TagBox["\"Semi-major Axis (AU)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->{{
     Thickness[0.004], 
     Thickness[0.004]}, {
     Thickness[0.004], 
     Thickness[0.004]}},
  FrameTicks->FrontEndValueCache[{{ResourceFunction["CombinePlots"][
       "CustomTicks"[True]][
       SlotSequence[1]]& , {{0., 
        FormBox[
        "\"\\!\\(\\*FormBox[RowBox[{\\\"-\\\", \\\"40\\\"}], TraditionalForm]\
\\)\"", TraditionalForm], {0.01, 0.}}, {0.016, 
        FormBox[
        "\"\\!\\(\\*FormBox[RowBox[{\\\"-\\\", \\\"20\\\"}], TraditionalForm]\
\\)\"", TraditionalForm], {0.01, 0.}}, {0.032, 
        FormBox[
        "\"\\!\\(\\*FormBox[\\\"0\\\", TraditionalForm]\\)\"", 
         TraditionalForm], {0.01, 0.}}, {0.048, 
        FormBox[
        "\"\\!\\(\\*FormBox[\\\"20\\\", TraditionalForm]\\)\"", 
         TraditionalForm], {0.01, 0.}}, {0.064, 
        FormBox[
        "\"\\!\\(\\*FormBox[\\\"40\\\", TraditionalForm]\\)\"", 
         TraditionalForm], {0.01, 0.}}, {0.08, 
        FormBox[
        "\"\\!\\(\\*FormBox[\\\"60\\\", TraditionalForm]\\)\"", 
         TraditionalForm], {0.01, 0.}}, {0.004, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.008, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.012, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.02, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.024, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.028, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.036000000000000004`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.04, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.044, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.052000000000000005`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.056, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.06, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.068, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.07200000000000001, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.07600000000000001, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}}}, {
     ResourceFunction["CombinePlots"][
       "CustomTicks"[True]][
       SlotSequence[1]]& , ResourceFunction["CombinePlots"][
       "CustomTicks"[False]][
       SlotSequence[1]]& }}, {{{{0., 
        FormBox[
        "\"\\!\\(\\*FormBox[\\\"0\\\", TraditionalForm]\\)\"", 
         TraditionalForm], {0.01, 0.}}, {0.02, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"0.\
02\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 0.02`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 2]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {0.04, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"0.\
04\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 0.04`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 2]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {0.06, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"0.\
06\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 0.06`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 2]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {0.08, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"0.\
08\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 0.08`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 2]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {0.005, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.01, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.015, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.025, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.03, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.035, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.045, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.05, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.055, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.065, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.07, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.075, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}}, {{
       0., 
        FormBox[
        "\"\\!\\(\\*FormBox[RowBox[{\\\"-\\\", \\\"40\\\"}], TraditionalForm]\
\\)\"", TraditionalForm], {0.01, 0.}}, {0.016, 
        FormBox[
        "\"\\!\\(\\*FormBox[RowBox[{\\\"-\\\", \\\"20\\\"}], TraditionalForm]\
\\)\"", TraditionalForm], {0.01, 0.}}, {0.032, 
        FormBox[
        "\"\\!\\(\\*FormBox[\\\"0\\\", TraditionalForm]\\)\"", 
         TraditionalForm], {0.01, 0.}}, {0.048, 
        FormBox[
        "\"\\!\\(\\*FormBox[\\\"20\\\", TraditionalForm]\\)\"", 
         TraditionalForm], {0.01, 0.}}, {0.064, 
        FormBox[
        "\"\\!\\(\\*FormBox[\\\"40\\\", TraditionalForm]\\)\"", 
         TraditionalForm], {0.01, 0.}}, {0.08, 
        FormBox[
        "\"\\!\\(\\*FormBox[\\\"60\\\", TraditionalForm]\\)\"", 
         TraditionalForm], {0.01, 0.}}, {0.004, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.008, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.012, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.02, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.024, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.028, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.036000000000000004`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.04, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.044, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.052000000000000005`, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.056, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.06, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.068, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.07200000000000001, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.07600000000000001, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}}}, {{{
       2., 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"2.0\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 2.`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {2.5, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"2.5\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 2.5`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {3., 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"3.0\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 3.`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {3.5, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"3.5\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 3.5`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {4., 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"4.0\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 4.`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {2.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}}, {{
       2., 
        FormBox[
         TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.01, 0.}}, {2.5, 
        FormBox[
         TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.01, 0.}}, {3., 
        FormBox[
         TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.01, 0.}}, {3.5, 
        FormBox[
         TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.01, 0.}}, {4., 
        FormBox[
         TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.01, 0.}}, {2.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}}}}],
  FrameTicksStyle->{{None, None}, {None, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True},
  PlotRange->{{2., 4.}, {0., 0.08}},
  PlotRangeClipping->True,
  PlotRangePadding->None,
  Prolog->{{}, 
    GeometricTransformationBox[{}, {{{1., 0.}, {0., 0.0008}}, {0., 0.032}}]},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8755949510786953`*^9, 3.875595035733034*^9, {3.87559512555196*^9, 
   3.8755951493549757`*^9}, 3.875595182973871*^9, 3.8755952147919073`*^9, 
   3.875596227824614*^9, 3.8755963852960653`*^9, 3.890976741863514*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"c26f952c-2e94-44a9-9de2-3bff3d066d18"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xlabel", "=", "\"\<Semi-major Axis (AU)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"y1label", "=", 
   RowBox[{"ToString", "[", 
    RowBox[{
     RowBox[{"Style", "[", 
      RowBox[{"\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
SubscriptBox[
StyleBox[\"I\", \"TI\"], \"forced\"], \" \", 
RowBox[{\"(\", \"deg.\", \")\"}]}], TraditionalForm], \"errors\" -> {}, \
\"input\" -> \"I_{\\\\rm{forced}}\\\\,(\\\\rm{deg.})\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\"", ",", "color1"}], "]"}], ",", 
     "StandardForm"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"y2label", "=", 
   RowBox[{"ToString", "[", 
    RowBox[{
     RowBox[{"Style", "[", 
      RowBox[{"\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
SubscriptBox[\"\[CapitalOmega]\", \"forced\"], \" \", 
RowBox[{\"(\", \"deg.\", \")\"}]}], TraditionalForm], \"errors\" -> {}, \
\"input\" -> \"\\\\Omega_{\\\\rm{forced}}\\\\,(\\\\rm{deg.})\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\"", ",", "color2"}], "]"}], ",", 
     "StandardForm"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"y1labelplain", "=", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
SubscriptBox[
StyleBox[\"I\", \"TI\"], \"forced\"], \" \", 
RowBox[{\"(\", \"deg.\", \")\"}]}], TraditionalForm], \"errors\" -> {}, \
\"input\" -> \"I_{\\\\rm{forced}}\\\\,(\\\\rm{deg.})\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"y2labelplain", "=", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
SubscriptBox[\"\[CapitalOmega]\", \"forced\"], \" \", 
RowBox[{\"(\", \"deg.\", \")\"}]}], TraditionalForm], \"errors\" -> {}, \
\"input\" -> \"\\\\Omega_{\\\\rm{forced}}\\\\,(\\\\rm{deg.})\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.869289947761011*^9, 3.869289969581517*^9}, {
   3.870332110433919*^9, 3.87033213656196*^9}, {3.8703321679305143`*^9, 
   3.870332169106471*^9}, 3.870333753167899*^9, 3.870333801080449*^9, {
   3.8706070315241737`*^9, 3.870607116081512*^9}, 3.870607168734023*^9, 
   3.87069254305085*^9, {3.8706925888486967`*^9, 3.870692598474683*^9}, {
   3.8755276336549253`*^9, 3.875527713180346*^9}, {3.875528177482769*^9, 
   3.875528183971979*^9}, {3.8755291302392683`*^9, 3.875529157443562*^9}, {
   3.875529631460299*^9, 3.87552967279491*^9}, {3.875529720349118*^9, 
   3.875529724770211*^9}, {3.875529777276381*^9, 3.875529832840493*^9}, {
   3.875594440922442*^9, 3.875594524395935*^9}, {3.87559522834733*^9, 
   3.875595282664501*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"1c852a40-908c-469c-96d4-01ba6aef229e"],

Cell["\<\
The secular resonance does not affect the forced inclination and node and so \
these plots are straight-forward with no gaps.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8755292242076817`*^9, 3.875529230222002*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ec8b280e-a379-450f-8e9c-ffcb546f0e95"],

Cell["\<\
Plot the forced inclination as a function of semi-major axis.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{
  3.875518167534189*^9, {3.875595689932396*^9, 3.875595691911777*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fc7af3fb-10c6-46e4-8e32-38feb7856b58"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pi", " ", "=", " ", "\n", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"ai", ",", " ", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}], ",", " ", "\n", 
    RowBox[{"Joined", "->", "True"}], ",", 
    RowBox[{"Frame", "->", "True"}], ",", " ", 
    RowBox[{"AxesOrigin", "->", 
     RowBox[{"{", 
      RowBox[{"2", ",", "0"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "->", 
     RowBox[{"Directive", "[", "color1", "]"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
    RowBox[{"FrameLabel", "->", 
     RowBox[{"{", 
      RowBox[{"xlabel", ",", "y1label"}], "}"}]}], ",", 
    RowBox[{"FrameStyle", "->", 
     RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
    RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.87068592287829*^9, 3.8706859228832207`*^9}, 
   3.870688854238531*^9, {3.8755190363696947`*^9, 3.875519060590534*^9}, {
   3.875527739792388*^9, 3.875527769070045*^9}, 3.875528240494081*^9, 
   3.875529998232946*^9, {3.8755300616520777`*^9, 3.875530114302553*^9}, {
   3.875530149731658*^9, 3.8755301957709417`*^9}, {3.875530237737084*^9, 
   3.8755302685909863`*^9}, {3.875530320417531*^9, 3.875530358876678*^9}, {
   3.8755304005464582`*^9, 3.875530432514462*^9}, {3.875530763725531*^9, 
   3.875530768086925*^9}, {3.875530867732513*^9, 3.875530935576428*^9}, {
   3.875530976078329*^9, 3.875530976435575*^9}, {3.875531099076928*^9, 
   3.875531111330882*^9}, 3.87553117577109*^9, 3.8755322307678127`*^9, {
   3.875595321968804*^9, 3.875595333998695*^9}, {3.875595368934393*^9, 
   3.875595439897847*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"ba273e45-8de7-4dbb-a8a8-9430a042a147"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw11XdUFdcWBvDbe0G5ktiuASwg8emz9/ms2AiKUaMQBZSgoAgW7FHsMSII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      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{2., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\\\\\\\\*TemplateBox[\
<|\\\\\\\\\\\\\\\"boxes\\\\\\\\\\\\\\\" -> \
FormBox[RowBox[{SubscriptBox[StyleBox[\\\\\\\\\\\\\\\"I\\\\\\\\\\\\\\\", \\\\\
\\\\\\\\\\\"TI\\\\\\\\\\\\\\\"], \\\\\\\\\\\\\\\"forced\\\\\\\\\\\\\\\"], \
\\\\\\\\\\\\\\\" \\\\\\\\\\\\\\\", RowBox[{\\\\\\\\\\\\\\\"(\\\\\\\\\\\\\\\", \
\\\\\\\\\\\\\\\"deg.\\\\\\\\\\\\\\\", \\\\\\\\\\\\\\\")\\\\\\\\\\\\\\\"}]}], \
TraditionalForm], \\\\\\\\\\\\\\\"errors\\\\\\\\\\\\\\\" -> {}, \
\\\\\\\\\\\\\\\"input\\\\\\\\\\\\\\\" -> \
\\\\\\\\\\\\\\\"I_{\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\rm{forced}}\\\\\\\\\\\\\\\\\
\\\\\\\\\\\\\\\\,(\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\rm{deg.})\\\\\\\\\\\\\\\", \
\\\\\\\\\\\\\\\"state\\\\\\\\\\\\\\\" -> \
\\\\\\\\\\\\\\\"Boxes\\\\\\\\\\\\\\\"|>,\\\\\\\\\\\\\\\"TeXAssistantTemplate\\\
\\\\\\\\\\\\\"]\\\\\\\\)\\\\\\\"\\\", RGBColor[0.368417`, 0.506779`, \
0.709798`], Rule[StripOnInput, False]]\\)\"", HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox["\"Semi-major Axis (AU)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{2., 4.}, {0., 3.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.81139644902964*^9, 3.8706090504061327`*^9, 3.870609120415668*^9, 
   3.870685957256855*^9, 3.870688860920761*^9, 3.87551472824432*^9, 
   3.87551892764815*^9, {3.875519129960182*^9, 3.875519137743284*^9}, 
   3.875527686779848*^9, {3.8755277428900967`*^9, 3.875527770148428*^9}, 
   3.8755280386649017`*^9, 3.87552819103078*^9, 3.875528241920244*^9, 
   3.87552914395822*^9, 3.875529245385024*^9, 3.8755296785299463`*^9, 
   3.875529729097908*^9, 3.875529810756791*^9, 3.87552992371817*^9, 
   3.875529999729478*^9, {3.875530094571294*^9, 3.8755301151290216`*^9}, 
   3.875530198429296*^9, {3.875530240597659*^9, 3.875530270389348*^9}, {
   3.875530324251432*^9, 3.8755303596081743`*^9}, {3.87553040279751*^9, 
   3.8755304342635393`*^9}, 3.875530769120287*^9, 3.875531015130205*^9, 
   3.8755311123923283`*^9, 3.875531177493362*^9, 3.8755312346143103`*^9, 
   3.875594163437879*^9, 3.8755942393833437`*^9, 3.875594484238008*^9, 
   3.875594711256115*^9, 3.87559529191288*^9, {3.875595323098856*^9, 
   3.875595336251873*^9}, {3.875595416254958*^9, 3.875595441203074*^9}, 
   3.8755962280610943`*^9, 3.8755963855378733`*^9, 3.8909767421356983`*^9},
 CellLabel->"Out[30]=",ExpressionUUID->"65ad66d7-40e0-472c-b8a6-b3aac3d7c15b"]
}, Open  ]],

Cell["\<\
Plot the forced longitude of ascending node as a function of semi-major axis.\
\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{
  3.875518167534189*^9, {3.875595705397235*^9, 3.8755957151620913`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d25aa204-4d24-406b-8d0e-fda50d95fbed"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pom", " ", "=", " ", "\n", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"aom", ",", " ", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "40"}], ",", "110"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Frame", "->", "True"}], ",", " ", 
    RowBox[{"Joined", "->", "True"}], ",", " ", 
    RowBox[{"AxesOrigin", "->", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "40"}]}], "}"}]}], ",", 
    RowBox[{"FrameLabel", "->", 
     RowBox[{"{", 
      RowBox[{"xlabel", ",", "y2label"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "->", 
     RowBox[{"Directive", "[", "color2", "]"}]}], ",", 
    RowBox[{"FrameStyle", "->", 
     RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
    RowBox[{"FrameTicks", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "40"}], ",", "0", ",", "40", ",", "80"}], "}"}], ",", 
         "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "2.5", ",", "3", ",", "3.5", ",", "4"}], "}"}], 
         ",", "None"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
    RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8706859359925613`*^9, 3.870685935997394*^9}, {
   3.870688864378887*^9, 3.8706888678549223`*^9}, 3.875519186707354*^9, {
   3.875519259950315*^9, 3.875519304335005*^9}, {3.875519337481758*^9, 
   3.875519391331622*^9}, {3.8755207450634527`*^9, 3.875520767443186*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"d502e5ea-7693-46b8-89e6-400fb37d5400"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.009166666666666668], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw11AlUTWsbB/Azn9MZXbrdG6nkusZPlyLqpr9CpDSfvWsp8iWfiljmTImI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      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{2., -40.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\\\\\\\\*TemplateBox[\
<|\\\\\\\\\\\\\\\"boxes\\\\\\\\\\\\\\\" -> \
FormBox[RowBox[{SubscriptBox[\\\\\\\\\\\\\\\"\[CapitalOmega]\\\\\\\\\\\\\\\", \
\\\\\\\\\\\\\\\"forced\\\\\\\\\\\\\\\"], \\\\\\\\\\\\\\\" \\\\\\\\\\\\\\\", \
RowBox[{\\\\\\\\\\\\\\\"(\\\\\\\\\\\\\\\", \\\\\\\\\\\\\\\"deg.\\\\\\\\\\\\\\\
\", \\\\\\\\\\\\\\\")\\\\\\\\\\\\\\\"}]}], TraditionalForm], \
\\\\\\\\\\\\\\\"errors\\\\\\\\\\\\\\\" -> {}, \\\\\\\\\\\\\\\"input\\\\\\\\\\\
\\\\\" -> \\\\\\\\\\\\\\\"\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\Omega_{\\\\\\\\\\\\\
\\\\\\\\\\\\\\\\\\\\rm{forced}}\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\,(\\\\\\\\\\\\\
\\\\\\\\\\\\\\\\\\\\rm{deg.})\\\\\\\\\\\\\\\", \
\\\\\\\\\\\\\\\"state\\\\\\\\\\\\\\\" -> \
\\\\\\\\\\\\\\\"Boxes\\\\\\\\\\\\\\\"|>,\\\\\\\\\\\\\\\"TeXAssistantTemplate\\\
\\\\\\\\\\\\\"]\\\\\\\\)\\\\\\\"\\\", RGBColor[0.880722`, 0.611041`, \
0.142051`], Rule[StripOnInput, False]]\\)\"", HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox["\"Semi-major Axis (AU)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{-40, 
       FormBox[
        RowBox[{"-", "40"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {40, 
       FormBox["40", TraditionalForm]}, {80, 
       FormBox["80", TraditionalForm]}}, None}, {{{2, 
       FormBox["2", TraditionalForm]}, {2.5, 
       FormBox["2.5`", TraditionalForm]}, {3, 
       FormBox["3", TraditionalForm]}, {3.5, 
       FormBox["3.5`", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{2., 4.}, {-40., 110.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.875519352020035*^9, 3.875519393555553*^9, {3.875520746679358*^9, 
   3.875520769605558*^9}, 3.875528194399424*^9, 3.875528252888308*^9, 
   3.875594167357031*^9, 3.8755942424674797`*^9, 3.8755945368749123`*^9, 
   3.875594714227232*^9, 3.8755952974499607`*^9, 3.8755962281480007`*^9, 
   3.875596385618328*^9, 3.890976742203136*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"1bf6ac0a-b236-4301-a8a5-eed327494702"]
}, Open  ]],

Cell[TextData[{
 "Now combine the two plots using the ",
 StyleBox["cp",
  FontWeight->"Bold"],
 " function."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.875594014337295*^9, 3.875594029382044*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1e2b9d31-9f9f-490e-925a-7f539eb345f2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cp", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{"ai", ",", " ", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}], ",", " ", "\n", 
     RowBox[{"Joined", "->", "True"}], ",", " ", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"Directive", "[", "color1", "]"}]}], ",", "\n", 
     RowBox[{"Frame", "->", "True"}], ",", " ", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "y1label"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"Directive", "[", "color1", "]"}]}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"aom", ",", " ", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "40"}], ",", "110"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", " ", 
     RowBox[{"Joined", "->", "True"}], ",", " ", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"2", ",", 
        RowBox[{"-", "40"}]}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "y2label"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"Directive", "[", "color2", "]"}]}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"FrameTicks", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "40"}], ",", "0", ",", "40", ",", "80"}], "}"}], ",",
           "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "2.5", ",", "3", ",", "3.5", ",", "4"}], "}"}], 
          ",", "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}], ",", 
   RowBox[{"\"\<AxesSides\>\"", "->", "\"\<TwoY\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.875527171363914*^9, 3.875527171934278*^9}, {
  3.87552720671906*^9, 3.875527230105403*^9}, {3.8755272911429033`*^9, 
  3.875527312260498*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"ed7d0650-74cc-4697-9eaf-0b9c7bf531b8"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw11XdUFdcWBvDbe0G5ktiuASwg8emz9/ms2AiKUaMQBZSgoAgW7FHsMSII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       "]]}}, {{}, {}}}, GeometricTransformationBox[{{}, {{}, {}, 
      {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
       0.009166666666666668], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJw11AlUTWsbB/Azn9MZXbrdG6nkusZPlyLqpr9CpDSfvWsp8iWfiljmTImI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        "]]}}, {{}, {}}}, {{{1., 0.}, {0., 0.02}}, {0., 0.8}}], 
   GeometricTransformationBox[{}, {{{1., 0.}, {0., 0.02}}, {0., 0.8}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{2., 0.},
  CoordinatesToolOptions:>{"CopiedValueFunction" -> Apply[{{Bottom, Left} -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& )[{#, #2}], {Bottom, Right} -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& )[{#, -40. + 50. #2}]}& ], "DisplayFunction" -> 
    Apply[Grid[{{
         Row[{
           Style["\[LeftArrow]", 20], " ", 
           ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )[{#, #2}]}]}, {
         Row[{
           ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )[{#, -40. + 50. #2}], " ", 
           Style["\[RightArrow]", 20]}]}}, Dividers -> Center, FrameStyle -> 
       Thickness[Large], Spacings -> 2]& ]},
  DisplayFunction->Identity,
  Epilog->{{}, 
    GeometricTransformationBox[{}, {{{1., 0.}, {0., 0.02}}, {0., 0.8}}]},
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\\\\\\\\*TemplateBox[\
<|\\\\\\\\\\\\\\\"boxes\\\\\\\\\\\\\\\" -> \
FormBox[RowBox[{SubscriptBox[StyleBox[\\\\\\\\\\\\\\\"I\\\\\\\\\\\\\\\", \\\\\
\\\\\\\\\\\"TI\\\\\\\\\\\\\\\"], \\\\\\\\\\\\\\\"forced\\\\\\\\\\\\\\\"], \
\\\\\\\\\\\\\\\" \\\\\\\\\\\\\\\", RowBox[{\\\\\\\\\\\\\\\"(\\\\\\\\\\\\\\\", \
\\\\\\\\\\\\\\\"deg.\\\\\\\\\\\\\\\", \\\\\\\\\\\\\\\")\\\\\\\\\\\\\\\"}]}], \
TraditionalForm], \\\\\\\\\\\\\\\"errors\\\\\\\\\\\\\\\" -> {}, \
\\\\\\\\\\\\\\\"input\\\\\\\\\\\\\\\" -> \
\\\\\\\\\\\\\\\"I_{\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\rm{forced}}\\\\\\\\\\\\\\\\\
\\\\\\\\\\\\\\\\,(\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\rm{deg.})\\\\\\\\\\\\\\\", \
\\\\\\\\\\\\\\\"state\\\\\\\\\\\\\\\" -> \
\\\\\\\\\\\\\\\"Boxes\\\\\\\\\\\\\\\"|>,\\\\\\\\\\\\\\\"TeXAssistantTemplate\\\
\\\\\\\\\\\\\"]\\\\\\\\)\\\\\\\"\\\", RGBColor[0.368417`, 0.506779`, \
0.709798`], Rule[StripOnInput, False]]\\)\"", HoldForm], TraditionalForm], 
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\\\\\\\\*TemplateBox[\
<|\\\\\\\\\\\\\\\"boxes\\\\\\\\\\\\\\\" -> \
FormBox[RowBox[{SubscriptBox[\\\\\\\\\\\\\\\"\[CapitalOmega]\\\\\\\\\\\\\\\", \
\\\\\\\\\\\\\\\"forced\\\\\\\\\\\\\\\"], \\\\\\\\\\\\\\\" \\\\\\\\\\\\\\\", \
RowBox[{\\\\\\\\\\\\\\\"(\\\\\\\\\\\\\\\", \\\\\\\\\\\\\\\"deg.\\\\\\\\\\\\\\\
\", \\\\\\\\\\\\\\\")\\\\\\\\\\\\\\\"}]}], TraditionalForm], \
\\\\\\\\\\\\\\\"errors\\\\\\\\\\\\\\\" -> {}, \\\\\\\\\\\\\\\"input\\\\\\\\\\\
\\\\\" -> \\\\\\\\\\\\\\\"\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\Omega_{\\\\\\\\\\\\\
\\\\\\\\\\\\\\\\\\\\rm{forced}}\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\,(\\\\\\\\\\\\\
\\\\\\\\\\\\\\\\\\\\rm{deg.})\\\\\\\\\\\\\\\", \
\\\\\\\\\\\\\\\"state\\\\\\\\\\\\\\\" -> \
\\\\\\\\\\\\\\\"Boxes\\\\\\\\\\\\\\\"|>,\\\\\\\\\\\\\\\"TeXAssistantTemplate\\\
\\\\\\\\\\\\\"]\\\\\\\\)\\\\\\\"\\\", RGBColor[0.880722`, 0.611041`, \
0.142051`], Rule[StripOnInput, False]]\\)\"", HoldForm], TraditionalForm]}, {
     FormBox[
      TagBox["\"Semi-major Axis (AU)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->{{
     Thickness[0.004], 
     Thickness[0.004]}, {
     Thickness[0.004], 
     Thickness[0.004]}},
  FrameTicks->FrontEndValueCache[{{ResourceFunction["CombinePlots"][
       "CustomTicks"[True]][
       SlotSequence[1]]& , {{0., 
        FormBox[
         RowBox[{"-", "40"}], TraditionalForm]}, {0.8, 
        FormBox["0", TraditionalForm]}, {1.6, 
        FormBox["40", TraditionalForm]}, {2.4000000000000004`, 
        FormBox["80", TraditionalForm]}}}, {ResourceFunction["CombinePlots"][
       "CustomTicks"[True]][
       SlotSequence[1]]& , ResourceFunction["CombinePlots"][
       "CustomTicks"[False]][
       SlotSequence[1]]& }}, {{{{0., 
        FormBox[
        "\"\\!\\(\\*FormBox[\\\"0\\\", TraditionalForm]\\)\"", 
         TraditionalForm], {0.01, 0.}}, {0.5, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"0.5\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 0.5`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {1., 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"1.0\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 1.`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {1.5, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"1.5\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 1.5`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {2., 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"2.0\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 2.`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {2.5, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"2.5\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 2.5`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {3., 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"3.0\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 3.`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {0.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {0.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {0.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {0.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {0.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {0.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {0.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {0.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {1.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {1.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {1.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {1.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {1.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {1.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {1.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {1.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}}, {{
       0., 
        FormBox[
         RowBox[{"-", "40"}], TraditionalForm]}, {0.8, 
        FormBox["0", TraditionalForm]}, {1.6, 
        FormBox["40", TraditionalForm]}, {2.4000000000000004`, 
        FormBox["80", TraditionalForm]}}}, {{{2., 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"2.0\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 2.`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {2.5, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"2.5\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 2.5`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {3., 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"3.0\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 3.`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {3.5, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"3.5\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 3.5`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {4., 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"4.0\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 4.`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {2.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}}, {{
       2., 
        FormBox[
         TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.01, 0.}}, {2.5, 
        FormBox[
         TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.01, 0.}}, {3., 
        FormBox[
         TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.01, 0.}}, {3.5, 
        FormBox[
         TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.01, 0.}}, {4., 
        FormBox[
         TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.01, 0.}}, {2.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}}}}],
  FrameTicksStyle->{{None, None}, {None, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True},
  PlotRange->{{2., 4.}, {0., 3.}},
  PlotRangeClipping->True,
  PlotRangePadding->None,
  Prolog->{{}, 
    GeometricTransformationBox[{}, {{{1., 0.}, {0., 0.02}}, {0., 0.8}}]},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.875527233080947*^9, {3.8755272933688498`*^9, 3.875527313943351*^9}, 
   3.875528201475008*^9, 3.875528256206407*^9, 3.875594171546028*^9, 
   3.875594246668249*^9, 3.875594542557235*^9, 3.875594716948007*^9, 
   3.875595467462092*^9, 3.875596228343487*^9, 3.875596385809725*^9, 
   3.890976742343932*^9},
 CellLabel->"Out[32]=",ExpressionUUID->"bf2f7c41-9924-42d9-81ca-f22f89f5cf8c"]
}, Open  ]],

Cell[TextData[{
 "Now combine the two plots using the ",
 StyleBox["cp",
  FontWeight->"Bold"],
 " function but using a dashed curve to denote the forced longitude of \
ascending node.  This gives Fig.7.16b."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.875594014337295*^9, 3.875594029382044*^9}, {
  3.875595845002529*^9, 3.8755959248768463`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"065c4f79-62e6-4d7c-9b38-9b994e83511b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cp", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{"ai", ",", " ", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}], ",", " ", "\n", 
     RowBox[{"Joined", "->", "True"}], ",", " ", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"Directive", "[", "color1", "]"}]}], ",", "\n", 
     RowBox[{"Frame", "->", "True"}], ",", " ", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "y1labelplain"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"Directive", "[", "color1", "]"}]}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"aom", ",", " ", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "40"}], ",", "110"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", " ", 
     RowBox[{"Joined", "->", "True"}], ",", " ", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"2", ",", 
        RowBox[{"-", "40"}]}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xlabel", ",", "y2labelplain"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"Directive", "[", 
       RowBox[{"color1", ",", "Dashed"}], "]"}]}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"FrameTicks", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "40"}], ",", "0", ",", "40", ",", "80"}], "}"}], ",",
           "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "2.5", ",", "3", ",", "3.5", ",", "4"}], "}"}], 
          ",", "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}], ",", 
   RowBox[{"\"\<AxesSides\>\"", "->", "\"\<TwoY\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.875527171363914*^9, 3.875527171934278*^9}, {
  3.87552720671906*^9, 3.875527230105403*^9}, {3.8755272911429033`*^9, 
  3.875527312260498*^9}, {3.875595504864169*^9, 3.8755955235832787`*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"211d3a3d-ddaa-4735-8410-4f6758f36ec8"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw11XdUFdcWBvDbe0G5ktiuASwg8emz9/ms2AiKUaMQBZSgoAgW7FHsMSII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       "]]}}, {{}, {}}}, GeometricTransformationBox[{{}, {{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.009166666666666668], AbsoluteThickness[1.6], Dashing[{Small, Small}],
        LineBox[CompressedData["
1:eJw11AlUTWsbB/Azn9MZXbrdG6nkusZPlyLqpr9CpDSfvWsp8iWfiljmTImI
lgqJSwPNJbm3iSiOMpMkQ4pEA5VPKL5M+er0vs9ae+31rr3X/32e97f2HrEk
xG0pj8PhXO+7+u+XAh+GdE/lgKOtWRpr6ePUVdYcbP7ier0szU7jds4wosOV
g6qlvka+/raaAG1xML3e6vTMH9Bs1s2zfxHKQYbD6qmvG2doYso/jlkYw8HG
jmXXYpZaadJW9SdyEJRu7+kdbqHRxp3jIP7vJdzIiWaayjv9xUF98wNew40J
mheh/YF9+91X1Wy2N9F86ksr/8iBSeTXJa3JMo22PSkXRXXfeqbdFsCoP86Q
i3c1bOLw6hEw0xYXHrYFgYNyJmKuNpCLuCbbtMnFU7BQ2yAXszMrnwpbrLBa
OzAXuyqTbDIbAW1cBBc35xk/8jtmh2N/9RcX98+a+Gj056B/Wt08LsIDH9+1
9ZmLiv5xy7noGXrQMjPAAdr2HnORMG38pvzpjnjTH9fBxeJhYc8m1zuRc+ZB
UxId4eTiDO3x6fJg0WlhLHZ2wVhtgzx4+YUVxDW7YIZ2YB4qoxYndQa6YsCD
hyORLp8/N7liwIMHt594WV6ubhjw4KHOLWX41kI3DHjwYHolye2k0h0DHn37
9Vx/+3ixOwY8eNDd2GOiyHXHgAcP/MVfu+Xv3THgwUPpGeO2PX94YMCDh9hN
N6W/BHlgwIOP1thPi2xOehAPPhqDXWrX1ngQDz72bNa7acDzJB58/NQcL4r9
lyfx4CN6vXmOgdqTePAxMtvooHiLJ/HgY9RdScb+ZE/iwUdZE9PerPEkHnzY
b+1cbt3oSTz4sLMz/X75uyfx4MMn9U7XUX018ehbIyut2UxNPASo3/bjfYWj
mngI0JD4d7qbv5p4CNBue+VpdqiaeAjwoe2jc2OMmngIkOKeeEyapiYeAuit
09lgdVZNPATQ+Bh27bypRqzWQ4BD91yTuurUxEOA6s6P/xztUBMPAZ4FJJiH
fVUTDwGW5VjrF0sZ4iHAVZNi79n6DPEQ4NSWn3WnjWaIhxCTLcfFHzFniIcQ
Cu+00OCZDPEQ4pRkeNFFJ4Z4CHFw+ZyUw14M8RDiybytP/f4M8RDiJn5b/3f
hDDEQwjn5C1rN4YyxEOIgJA9l07uYohHX15Bqd+KaAbaccuFqGoQGzUeYYiH
EM8KywJ7TzDEQwjY/LryTjZDPEQY6aenXJDPEA8R/l1d9W73eYZ4iHDbxjE8
tJwhHiKIc9t7xt9iiIcIvSH+XknVDPEQYeuE9aEPahniIQKSLSTVzxniIcLM
gHF74lsZ4iHC0moRM/q/DPEQQd/AqSiiiyEeIpiWnLhU8Jl6iPBW82FdwQ/q
IUKaJKx0t5AlHmI0fcjwMZWxxEOM5ISjsjODWOIhRnvuaz+xHks8xJhY0ts6
fRhLPMQ43xykmGvMEg8x1huPnmI2iiUeYjw0y8/9NpYlHmKs3Dk2P30iSzzE
mOCNtaZmLPEQo9R5/JDjFizxEKMAoSfbrFjiIYZyfNNvBmCJhwT3TH7Em81i
iYcE4g1fWv6YyxIPCXJE0z/qOrLEQwKfvM7ERmeWeEjwOrXgTJw7Szwk6N7B
eT+JYYmHBLziIqMSb5Z4SHCpK+r9OF+WePQ9t9upG+nHEg8JKiY5mFb7s8RD
gtrMpBei/7B4qfWQYPa9rCtjg1jiIUFCuEuQ5UrqoYPt0fuXTF9NPXQQYVcw
afRaFuZaDx20Rp71FmygHjp4Ur3Ou3oT9eh7f8rbrOgtLLTtrdLBwjdhJX9u
px46CAr5/Wv9Duqhgw+r02qDd1EPHfi2XTrXuZt66OCae3Cv/17qoYO65T2S
yijqoYPKpdPMx0RTDynOC/Nq18dSDylyV+TNLzlIPaRgpbufd8ZRDykaDh1r
GnqEekixxikqzfIv6iHF3QTnYOfj1EOKrMEe4V6J1EOKjK+Hx3slUw8p0mPK
chacpB59+TVTYZlKPaR4aztvnEE69ejr13FiencG9ZCi5eLvHRVZ1EOGNaNi
zPflUA8ZPCd3nbXPpR4yxE03zvl2mnrIIKyaOiP7DPWQ4cCBC+lO/1APGcJM
Mwe151MPGVzz1p3eVkg9ZLDhTMmWFVMPGW68O2h64Cz1kOHX1e2BqhLqIUOW
o8uu3eephwzNTsmpny5QDzlm1+3sXFRGPeQ4L9+zv/wi9ZBD7qmfYqihHnI4
pCS4rL1MPeQYZ7jyQkU59ZDj/rZOvuIK9ZDDojvGweUq9ZD3fS8P8vZfox5y
HJrq53z1OvWQY9+P3nn/u0E95HDWS7ww8hb1kMOoe7vG4Tb1kCOo99Oa4DvU
Q4F52YXvIiuphwKiEbkuJ+5SDwWy44xO51dRDwUYwwxDzT3qoYD1ykllN6qp
hwLpNkNO3LlPPRQYdYTXcLuGeihQXGm8/9oD6qFARWBveelD6qHAsqrkuLxH
1EOBJ4U79BIeUw8FZGGJCyNqqYcSvsErQgOfUA8lhsa8C59fRz2U2FCUFzmm
nnooUWJYmsh9Sj2U4OqW1Tx6Sj2UmLCozSrrGfVQYkqK6tW6BuqhRHDs0Rab
59RDiQLpPntRI/VQYojxPoObjdRDicyuF2siX1APJQz3hi2c9ZJ6KFG08Xvz
t5fUQ4XqqOPD8puoh6rvfzhf6d9MPVTYMuf0rcEt1EOFu5d1fS+2UA8VTp3a
+zCglXqocPTLLWv5K+qhwszrLql5r6iHCiY+CwYveE09VLC2LIxvf009VIjq
nfTnrjbqoULp/GnKYe3UQ4X3h7/8cqadegxCV8sqf3Sw+D/9RV0t
        "]]}}, {{}, {}}}, {{{1., 0.}, {0., 0.02}}, {0., 0.8}}], 
   GeometricTransformationBox[{}, {{{1., 0.}, {0., 0.02}}, {0., 0.8}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{2., 0.},
  CoordinatesToolOptions:>{"CopiedValueFunction" -> Apply[{{Bottom, Left} -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& )[{#, #2}], {Bottom, Right} -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& )[{#, -40. + 50. #2}]}& ], "DisplayFunction" -> 
    Apply[Grid[{{
         Row[{
           Style["\[LeftArrow]", 20], " ", 
           ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )[{#, #2}]}]}, {
         Row[{
           ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )[{#, -40. + 50. #2}], " ", 
           Style["\[RightArrow]", 20]}]}}, Dividers -> Center, FrameStyle -> 
       Thickness[Large], Spacings -> 2]& ]},
  DisplayFunction->Identity,
  Epilog->{{}, 
    GeometricTransformationBox[{}, {{{1., 0.}, {0., 0.02}}, {0., 0.8}}]},
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[RowBox[{SubscriptBox[StyleBox[\\\"I\\\", \\\"TI\\\"], \
\\\"forced\\\"], \\\" \\\", RowBox[{\\\"(\\\", \\\"deg.\\\", \\\")\\\"}]}], \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"I_{\\\\\\\\rm{forced}}\\\\\\\\,(\\\\\\\\rm{deg.})\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", HoldForm], 
      TraditionalForm], 
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[RowBox[{SubscriptBox[\\\"\[CapitalOmega]\\\", \\\"forced\\\"], \\\" \
\\\", RowBox[{\\\"(\\\", \\\"deg.\\\", \\\")\\\"}]}], TraditionalForm], \
\\\"errors\\\" -> {}, \\\"input\\\" -> \\\"\\\\\\\\Omega_{\\\\\\\\rm{forced}}\
\\\\\\\\,(\\\\\\\\rm{deg.})\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", HoldForm], 
      TraditionalForm]}, {
     FormBox[
      TagBox["\"Semi-major Axis (AU)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->{{
     Thickness[0.004], 
     Thickness[0.004]}, {
     Thickness[0.004], 
     Thickness[0.004]}},
  FrameTicks->FrontEndValueCache[{{ResourceFunction["CombinePlots"][
       "CustomTicks"[True]][
       SlotSequence[1]]& , {{0., 
        FormBox[
         RowBox[{"-", "40"}], TraditionalForm]}, {0.8, 
        FormBox["0", TraditionalForm]}, {1.6, 
        FormBox["40", TraditionalForm]}, {2.4000000000000004`, 
        FormBox["80", TraditionalForm]}}}, {ResourceFunction["CombinePlots"][
       "CustomTicks"[True]][
       SlotSequence[1]]& , ResourceFunction["CombinePlots"][
       "CustomTicks"[False]][
       SlotSequence[1]]& }}, {{{{0., 
        FormBox[
        "\"\\!\\(\\*FormBox[\\\"0\\\", TraditionalForm]\\)\"", 
         TraditionalForm], {0.01, 0.}}, {0.5, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"0.5\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 0.5`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {1., 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"1.0\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 1.`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {1.5, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"1.5\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 1.5`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {2., 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"2.0\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 2.`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {2.5, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"2.5\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 2.5`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {3., 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"3.0\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 3.`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {0.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {0.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {0.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {0.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {0.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {0.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {0.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {0.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {1.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {1.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {1.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {1.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {1.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {1.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {1.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {1.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}}, {{
       0., 
        FormBox[
         RowBox[{"-", "40"}], TraditionalForm]}, {0.8, 
        FormBox["0", TraditionalForm]}, {1.6, 
        FormBox["40", TraditionalForm]}, {2.4000000000000004`, 
        FormBox["80", TraditionalForm]}}}, {{{2., 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"2.0\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 2.`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {2.5, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"2.5\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 2.5`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {3., 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"3.0\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 3.`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {3.5, 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"3.5\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 3.5`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {4., 
        FormBox[
        "\"\\!\\(\\*FormBox[TagBox[InterpretationBox[StyleBox[\\\"\\\\\\\"4.0\
\\\\\\\"\\\", Rule[ShowStringCharacters, False]], 4.`15.954589770191003, \
Rule[AutoDelete, True]], Function[NumberForm[Slot[1], \
List[DirectedInfinity[1], 1]]]], TraditionalForm]\\)\"", TraditionalForm], {
        0.01, 0.}}, {2.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}}, {{
       2., 
        FormBox[
         TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.01, 0.}}, {2.5, 
        FormBox[
         TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.01, 0.}}, {3., 
        FormBox[
         TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.01, 0.}}, {3.5, 
        FormBox[
         TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.01, 0.}}, {4., 
        FormBox[
         TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.01, 0.}}, {2.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {2.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.1, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.2, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.3, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.4, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.6, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.7, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.8, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {3.9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}}}}],
  FrameTicksStyle->{{None, None}, {None, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True},
  PlotRange->{{2., 4.}, {0., 3.}},
  PlotRangeClipping->True,
  PlotRangePadding->None,
  Prolog->{{}, 
    GeometricTransformationBox[{}, {{{1., 0.}, {0., 0.02}}, {0., 0.8}}]},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.875595525007409*^9, 3.875596228671605*^9, 
  3.875596386178504*^9, 3.890976742597722*^9},
 CellLabel->"Out[33]=",ExpressionUUID->"6d9bd349-21cd-4a68-80e8-7ef8a1c0757c"]
}, Open  ]]
},
WindowToolbars->"MultipurposeBar",
CellGrouping->Manual,
WindowSize->{1022, 664},
WindowMargins->{{84, Automatic}, {Automatic, 25}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"5f630fc1-e359-4242-a8d7-1aad26fb2b31"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 439, 9, 53, "Text",ExpressionUUID->"5a7d6619-6bae-4c0f-83f3-957cc8244682"],
Cell[1000, 31, 110, 0, 67, "Section",ExpressionUUID->"ed1aa644-8af7-45fd-90c6-3a7e9c066dbb"],
Cell[1113, 33, 290, 8, 49, "Text",ExpressionUUID->"c125199a-ba4d-48c1-a4cd-efb6154951a4"],
Cell[1406, 43, 1204, 31, 115, "Input",ExpressionUUID->"6b115696-9890-42b3-8505-a71b37be217c"],
Cell[2613, 76, 572, 17, 76, "Text",ExpressionUUID->"4b41b6e1-035e-4114-b201-ae8aa72b905f"],
Cell[3188, 95, 20424, 495, 1921, "Input",ExpressionUUID->"c40b1e72-4a7a-4efe-8bd9-416f4529b2b7"],
Cell[23615, 592, 205, 5, 53, "Text",ExpressionUUID->"1719780f-8de4-4a4f-84cf-3a1da27b8d59"],
Cell[23823, 599, 556, 13, 52, "Input",ExpressionUUID->"7166eb21-c074-45bb-bf5c-dea5ec22c86c"],
Cell[24382, 614, 151, 3, 53, "Text",ExpressionUUID->"a08bf566-8ee8-4879-8e19-3cb0d2a7e628"],
Cell[24536, 619, 268, 5, 30, "Input",ExpressionUUID->"57b23ba4-9550-4348-a59b-465518fe23ac"],
Cell[24807, 626, 307, 7, 76, "Text",ExpressionUUID->"c507b30c-7aaa-421d-8192-ab03f99aca75"],
Cell[25117, 635, 1287, 38, 94, "Input",ExpressionUUID->"57174013-42ef-4692-937e-496d9f64b056"],
Cell[26407, 675, 408, 9, 76, "Text",ExpressionUUID->"4a093312-3529-47ac-8119-521634508e47"],
Cell[26818, 686, 498, 14, 30, "Input",ExpressionUUID->"b5685f15-d73a-42c3-9a86-08694146b293"],
Cell[27319, 702, 499, 14, 30, "Input",ExpressionUUID->"cdab3668-331e-4d0a-9431-3ba899767a5f"],
Cell[27821, 718, 299, 7, 53, "Text",ExpressionUUID->"91e4047d-8e65-4b31-8a8a-0c9f720970ed"],
Cell[28123, 727, 547, 15, 30, "Input",ExpressionUUID->"a1641c6c-1870-4c0f-9b2f-824ef8536360"],
Cell[28673, 744, 285, 6, 30, "Input",ExpressionUUID->"f44504b8-930b-4e3a-a9d9-2ad821643e54"],
Cell[28961, 752, 226, 4, 53, "Text",ExpressionUUID->"1088118a-c749-40cf-944a-014a651d3e46"],
Cell[29190, 758, 319, 7, 33, "Input",ExpressionUUID->"8b536e59-af7d-4f88-9380-fac0d0fff6d4"],
Cell[29512, 767, 315, 7, 33, "Input",ExpressionUUID->"84729db2-5cde-4be1-ab57-d6fc6e4abf41"],
Cell[29830, 776, 656, 10, 53, "Text",ExpressionUUID->"1c35af96-a24b-4136-9ae5-b8ea0dace3b5"],
Cell[30489, 788, 2354, 48, 122, "Input",ExpressionUUID->"f08b1df7-ea5a-49a0-b8d8-607a67abf2c8"],
Cell[32846, 838, 238, 6, 53, "Text",ExpressionUUID->"3ea90b82-6d57-423e-b1f3-e533b9fde852"],
Cell[CellGroupData[{
Cell[33109, 848, 1450, 35, 73, "Input",ExpressionUUID->"a9fe61c7-c09e-462a-91f4-ec865fe9e8f3"],
Cell[34562, 885, 7653, 163, 250, "Output",ExpressionUUID->"eaac74dd-19c7-43b7-9060-b9efa4fc5820"]
}, Open  ]],
Cell[42230, 1051, 182, 3, 53, "Text",ExpressionUUID->"90f8a116-4151-4f84-841e-ecbe105801ed"],
Cell[CellGroupData[{
Cell[42437, 1058, 1423, 36, 73, "Input",ExpressionUUID->"81f84c76-2880-4498-9d25-28120db85afc"],
Cell[43863, 1096, 7970, 165, 251, "Output",ExpressionUUID->"4f3276d7-7629-40bf-8d3f-14f69ded6366"]
}, Open  ]],
Cell[51848, 1264, 672, 15, 99, "Text",ExpressionUUID->"cc462445-6811-44f2-8ec9-9691bf8635a7"],
Cell[52523, 1281, 328, 7, 30, "Input",ExpressionUUID->"664c68d9-b11d-4547-be01-b8336599da82"],
Cell[52854, 1290, 297, 9, 53, "Text",ExpressionUUID->"6f81f977-e643-46cc-8f67-837cfed3d32d"],
Cell[CellGroupData[{
Cell[53176, 1303, 2578, 66, 136, "Input",ExpressionUUID->"2a6d126d-d350-4cbb-8709-61f7f414155a"],
Cell[55757, 1371, 26107, 561, 224, "Output",ExpressionUUID->"23939e7d-d05f-4c05-8d95-0f454f821a00"]
}, Open  ]],
Cell[81879, 1935, 441, 11, 53, "Text",ExpressionUUID->"f699bdf6-1fb5-4c96-9174-ed7965eefb71"],
Cell[CellGroupData[{
Cell[82345, 1950, 2921, 73, 157, "Input",ExpressionUUID->"590b9f51-d578-48e3-99d5-eccf40044674"],
Cell[85269, 2025, 25177, 548, 224, "Output",ExpressionUUID->"c26f952c-2e94-44a9-9de2-3bff3d066d18"]
}, Open  ]],
Cell[110461, 2576, 2748, 56, 122, "Input",ExpressionUUID->"1c852a40-908c-469c-96d4-01ba6aef229e"],
Cell[113212, 2634, 327, 7, 53, "Text",ExpressionUUID->"ec8b280e-a379-450f-8e9c-ffcb546f0e95"],
Cell[113542, 2643, 286, 7, 53, "Text",ExpressionUUID->"fc7af3fb-10c6-46e4-8e32-38feb7856b58"],
Cell[CellGroupData[{
Cell[113853, 2654, 1999, 41, 115, "Input",ExpressionUUID->"ba273e45-8de7-4dbb-a8a8-9430a042a147"],
Cell[115855, 2697, 8540, 172, 255, "Output",ExpressionUUID->"65ad66d7-40e0-472c-b8a6-b3aac3d7c15b"]
}, Open  ]],
Cell[124410, 2872, 306, 8, 53, "Text",ExpressionUUID->"d25aa204-4d24-406b-8d0e-fda50d95fbed"],
Cell[CellGroupData[{
Cell[124741, 2884, 1951, 49, 115, "Input",ExpressionUUID->"d502e5ea-7693-46b8-89e6-400fb37d5400"],
Cell[126695, 2935, 8078, 170, 247, "Output",ExpressionUUID->"1bf6ac0a-b236-4301-a8a5-eed327494702"]
}, Open  ]],
Cell[134788, 3108, 297, 9, 53, "Text",ExpressionUUID->"1e2b9d31-9f9f-490e-925a-7f539eb345f2"],
Cell[CellGroupData[{
Cell[135110, 3121, 3121, 80, 178, "Input",ExpressionUUID->"ed7d0650-74cc-4697-9eaf-0b9c7bf531b8"],
Cell[138234, 3203, 23130, 462, 229, "Output",ExpressionUUID->"bf2f7c41-9924-42d9-81ca-f22f89f5cf8c"]
}, Open  ]],
Cell[161379, 3668, 447, 11, 76, "Text",ExpressionUUID->"065c4f79-62e6-4d7c-9b38-9b994e83511b"],
Cell[CellGroupData[{
Cell[161851, 3683, 3212, 81, 178, "Input",ExpressionUUID->"211d3a3d-ddaa-4735-8410-4f6758f36ec8"],
Cell[165066, 3766, 21830, 444, 252, "Output",ExpressionUUID->"6d9bd349-21cd-4a68-80e8-7ef8a1c0757c"]
}, Open  ]]
}
]
*)

